@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import AcceleratorTypesTransport
-from .rest import AcceleratorTypesRestTransport
-from .rest import AcceleratorTypesRestInterceptor
-
+from .rest import AcceleratorTypesRestInterceptor, AcceleratorTypesRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[AcceleratorTypesTransport]]
