@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.addresses import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import AddressesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, AddressesTransport
 from .transports.rest import AddressesRestTransport
 
 
@@ -56,7 +69,7 @@ class AddressesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[AddressesTransport]:
         """Returns an appropriate transport class.
 
@@ -254,7 +267,7 @@ class AddressesClient(metaclass=AddressesClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -309,8 +322,8 @@ class AddressesClient(metaclass=AddressesClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, AddressesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, AddressesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the addresses client.
@@ -327,7 +340,7 @@ class AddressesClient(metaclass=AddressesClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -357,6 +370,7 @@ class AddressesClient(metaclass=AddressesClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -409,11 +423,11 @@ class AddressesClient(metaclass=AddressesClientMeta):
 
     def aggregated_list(
         self,
-        request: Union[compute.AggregatedListAddressesRequest, dict] = None,
+        request: Optional[Union[compute.AggregatedListAddressesRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Retrieves an aggregated list of addresses.
@@ -494,13 +508,13 @@ class AddressesClient(metaclass=AddressesClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteAddressRequest, dict] = None,
+        request: Optional[Union[compute.DeleteAddressRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        address: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        address: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified address resource.
@@ -593,13 +607,13 @@ class AddressesClient(metaclass=AddressesClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteAddressRequest, dict] = None,
+        request: Optional[Union[compute.DeleteAddressRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        address: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        address: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified address resource.
@@ -717,13 +731,13 @@ class AddressesClient(metaclass=AddressesClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetAddressRequest, dict] = None,
+        request: Optional[Union[compute.GetAddressRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        address: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        address: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Address:
         r"""Returns the specified address resource.
@@ -820,13 +834,13 @@ class AddressesClient(metaclass=AddressesClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertAddressRequest, dict] = None,
+        request: Optional[Union[compute.InsertAddressRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        address_resource: compute.Address = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        address_resource: Optional[compute.Address] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates an address resource in the specified project
@@ -917,13 +931,13 @@ class AddressesClient(metaclass=AddressesClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertAddressRequest, dict] = None,
+        request: Optional[Union[compute.InsertAddressRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        address_resource: compute.Address = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        address_resource: Optional[compute.Address] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates an address resource in the specified project
@@ -1039,12 +1053,12 @@ class AddressesClient(metaclass=AddressesClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListAddressesRequest, dict] = None,
+        request: Optional[Union[compute.ListAddressesRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves a list of addresses contained within the
@@ -1138,14 +1152,16 @@ class AddressesClient(metaclass=AddressesClientMeta):
 
     def set_labels_unary(
         self,
-        request: Union[compute.SetLabelsAddressRequest, dict] = None,
+        request: Optional[Union[compute.SetLabelsAddressRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        resource: str = None,
-        region_set_labels_request_resource: compute.RegionSetLabelsRequest = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        resource: Optional[str] = None,
+        region_set_labels_request_resource: Optional[
+            compute.RegionSetLabelsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Sets the labels on an Address. To learn more about
@@ -1250,14 +1266,16 @@ class AddressesClient(metaclass=AddressesClientMeta):
 
     def set_labels(
         self,
-        request: Union[compute.SetLabelsAddressRequest, dict] = None,
+        request: Optional[Union[compute.SetLabelsAddressRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        resource: str = None,
-        region_set_labels_request_resource: compute.RegionSetLabelsRequest = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        resource: Optional[str] = None,
+        region_set_labels_request_resource: Optional[
+            compute.RegionSetLabelsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Sets the labels on an Address. To learn more about
@@ -1399,14 +1417,9 @@ class AddressesClient(metaclass=AddressesClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("AddressesClient",)
