@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.backend_buckets import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import BackendBucketsTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, BackendBucketsTransport
 from .transports.rest import BackendBucketsRestTransport
 
 
@@ -58,7 +71,7 @@ class BackendBucketsClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[BackendBucketsTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, BackendBucketsTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, BackendBucketsTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the backend buckets client.
@@ -329,7 +342,7 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,13 +425,15 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def add_signed_url_key_unary(
         self,
-        request: Union[compute.AddSignedUrlKeyBackendBucketRequest, dict] = None,
+        request: Optional[
+            Union[compute.AddSignedUrlKeyBackendBucketRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        backend_bucket: str = None,
-        signed_url_key_resource: compute.SignedUrlKey = None,
+        project: Optional[str] = None,
+        backend_bucket: Optional[str] = None,
+        signed_url_key_resource: Optional[compute.SignedUrlKey] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Adds a key for validating requests with signed URLs
@@ -512,13 +528,15 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def add_signed_url_key(
         self,
-        request: Union[compute.AddSignedUrlKeyBackendBucketRequest, dict] = None,
+        request: Optional[
+            Union[compute.AddSignedUrlKeyBackendBucketRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        backend_bucket: str = None,
-        signed_url_key_resource: compute.SignedUrlKey = None,
+        project: Optional[str] = None,
+        backend_bucket: Optional[str] = None,
+        signed_url_key_resource: Optional[compute.SignedUrlKey] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Adds a key for validating requests with signed URLs
@@ -637,12 +655,12 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteBackendBucketRequest, dict] = None,
+        request: Optional[Union[compute.DeleteBackendBucketRequest, dict]] = None,
         *,
-        project: str = None,
-        backend_bucket: str = None,
+        project: Optional[str] = None,
+        backend_bucket: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified BackendBucket resource.
@@ -727,12 +745,12 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteBackendBucketRequest, dict] = None,
+        request: Optional[Union[compute.DeleteBackendBucketRequest, dict]] = None,
         *,
-        project: str = None,
-        backend_bucket: str = None,
+        project: Optional[str] = None,
+        backend_bucket: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified BackendBucket resource.
@@ -841,13 +859,15 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def delete_signed_url_key_unary(
         self,
-        request: Union[compute.DeleteSignedUrlKeyBackendBucketRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteSignedUrlKeyBackendBucketRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        backend_bucket: str = None,
-        key_name: str = None,
+        project: Optional[str] = None,
+        backend_bucket: Optional[str] = None,
+        key_name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes a key for validating requests with signed
@@ -944,13 +964,15 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def delete_signed_url_key(
         self,
-        request: Union[compute.DeleteSignedUrlKeyBackendBucketRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteSignedUrlKeyBackendBucketRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        backend_bucket: str = None,
-        key_name: str = None,
+        project: Optional[str] = None,
+        backend_bucket: Optional[str] = None,
+        key_name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes a key for validating requests with signed
@@ -1071,12 +1093,12 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetBackendBucketRequest, dict] = None,
+        request: Optional[Union[compute.GetBackendBucketRequest, dict]] = None,
         *,
-        project: str = None,
-        backend_bucket: str = None,
+        project: Optional[str] = None,
+        backend_bucket: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.BackendBucket:
         r"""Returns the specified BackendBucket resource. Gets a
@@ -1166,12 +1188,12 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertBackendBucketRequest, dict] = None,
+        request: Optional[Union[compute.InsertBackendBucketRequest, dict]] = None,
         *,
-        project: str = None,
-        backend_bucket_resource: compute.BackendBucket = None,
+        project: Optional[str] = None,
+        backend_bucket_resource: Optional[compute.BackendBucket] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a BackendBucket resource in the specified
@@ -1250,12 +1272,12 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertBackendBucketRequest, dict] = None,
+        request: Optional[Union[compute.InsertBackendBucketRequest, dict]] = None,
         *,
-        project: str = None,
-        backend_bucket_resource: compute.BackendBucket = None,
+        project: Optional[str] = None,
+        backend_bucket_resource: Optional[compute.BackendBucket] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a BackendBucket resource in the specified
@@ -1358,11 +1380,11 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListBackendBucketsRequest, dict] = None,
+        request: Optional[Union[compute.ListBackendBucketsRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves the list of BackendBucket resources
@@ -1446,13 +1468,13 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def patch_unary(
         self,
-        request: Union[compute.PatchBackendBucketRequest, dict] = None,
+        request: Optional[Union[compute.PatchBackendBucketRequest, dict]] = None,
         *,
-        project: str = None,
-        backend_bucket: str = None,
-        backend_bucket_resource: compute.BackendBucket = None,
+        project: Optional[str] = None,
+        backend_bucket: Optional[str] = None,
+        backend_bucket_resource: Optional[compute.BackendBucket] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Updates the specified BackendBucket resource with the
@@ -1547,13 +1569,13 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def patch(
         self,
-        request: Union[compute.PatchBackendBucketRequest, dict] = None,
+        request: Optional[Union[compute.PatchBackendBucketRequest, dict]] = None,
         *,
-        project: str = None,
-        backend_bucket: str = None,
-        backend_bucket_resource: compute.BackendBucket = None,
+        project: Optional[str] = None,
+        backend_bucket: Optional[str] = None,
+        backend_bucket_resource: Optional[compute.BackendBucket] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Updates the specified BackendBucket resource with the
@@ -1672,13 +1694,17 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def set_edge_security_policy_unary(
         self,
-        request: Union[compute.SetEdgeSecurityPolicyBackendBucketRequest, dict] = None,
+        request: Optional[
+            Union[compute.SetEdgeSecurityPolicyBackendBucketRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        backend_bucket: str = None,
-        security_policy_reference_resource: compute.SecurityPolicyReference = None,
+        project: Optional[str] = None,
+        backend_bucket: Optional[str] = None,
+        security_policy_reference_resource: Optional[
+            compute.SecurityPolicyReference
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Sets the edge security policy for the specified
@@ -1776,13 +1802,17 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def set_edge_security_policy(
         self,
-        request: Union[compute.SetEdgeSecurityPolicyBackendBucketRequest, dict] = None,
+        request: Optional[
+            Union[compute.SetEdgeSecurityPolicyBackendBucketRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        backend_bucket: str = None,
-        security_policy_reference_resource: compute.SecurityPolicyReference = None,
+        project: Optional[str] = None,
+        backend_bucket: Optional[str] = None,
+        security_policy_reference_resource: Optional[
+            compute.SecurityPolicyReference
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Sets the edge security policy for the specified
@@ -1904,13 +1934,13 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def update_unary(
         self,
-        request: Union[compute.UpdateBackendBucketRequest, dict] = None,
+        request: Optional[Union[compute.UpdateBackendBucketRequest, dict]] = None,
         *,
-        project: str = None,
-        backend_bucket: str = None,
-        backend_bucket_resource: compute.BackendBucket = None,
+        project: Optional[str] = None,
+        backend_bucket: Optional[str] = None,
+        backend_bucket_resource: Optional[compute.BackendBucket] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Updates the specified BackendBucket resource with the
@@ -2003,13 +2033,13 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
 
     def update(
         self,
-        request: Union[compute.UpdateBackendBucketRequest, dict] = None,
+        request: Optional[Union[compute.UpdateBackendBucketRequest, dict]] = None,
         *,
-        project: str = None,
-        backend_bucket: str = None,
-        backend_bucket_resource: compute.BackendBucket = None,
+        project: Optional[str] = None,
+        backend_bucket: Optional[str] = None,
+        backend_bucket_resource: Optional[compute.BackendBucket] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Updates the specified BackendBucket resource with the
@@ -2138,14 +2168,9 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("BackendBucketsClient",)
