@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import FirewallPoliciesTransport
-from .rest import FirewallPoliciesRestTransport
-from .rest import FirewallPoliciesRestInterceptor
-
+from .rest import FirewallPoliciesRestInterceptor, FirewallPoliciesRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[FirewallPoliciesTransport]]
