@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.firewalls import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import FirewallsTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, FirewallsTransport
 from .transports.rest import FirewallsRestTransport
 
 
@@ -56,7 +69,7 @@ class FirewallsClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[FirewallsTransport]:
         """Returns an appropriate transport class.
 
@@ -254,7 +267,7 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -309,8 +322,8 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, FirewallsTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, FirewallsTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the firewalls client.
@@ -327,7 +340,7 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -357,6 +370,7 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -409,12 +423,12 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteFirewallRequest, dict] = None,
+        request: Optional[Union[compute.DeleteFirewallRequest, dict]] = None,
         *,
-        project: str = None,
-        firewall: str = None,
+        project: Optional[str] = None,
+        firewall: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified firewall.
@@ -497,12 +511,12 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteFirewallRequest, dict] = None,
+        request: Optional[Union[compute.DeleteFirewallRequest, dict]] = None,
         *,
-        project: str = None,
-        firewall: str = None,
+        project: Optional[str] = None,
+        firewall: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified firewall.
@@ -609,12 +623,12 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetFirewallRequest, dict] = None,
+        request: Optional[Union[compute.GetFirewallRequest, dict]] = None,
         *,
-        project: str = None,
-        firewall: str = None,
+        project: Optional[str] = None,
+        firewall: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Firewall:
         r"""Returns the specified firewall.
@@ -699,12 +713,12 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertFirewallRequest, dict] = None,
+        request: Optional[Union[compute.InsertFirewallRequest, dict]] = None,
         *,
-        project: str = None,
-        firewall_resource: compute.Firewall = None,
+        project: Optional[str] = None,
+        firewall_resource: Optional[compute.Firewall] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a firewall rule in the specified project
@@ -783,12 +797,12 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertFirewallRequest, dict] = None,
+        request: Optional[Union[compute.InsertFirewallRequest, dict]] = None,
         *,
-        project: str = None,
-        firewall_resource: compute.Firewall = None,
+        project: Optional[str] = None,
+        firewall_resource: Optional[compute.Firewall] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a firewall rule in the specified project
@@ -891,11 +905,11 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListFirewallsRequest, dict] = None,
+        request: Optional[Union[compute.ListFirewallsRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves the list of firewall rules available to the
@@ -977,13 +991,13 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
 
     def patch_unary(
         self,
-        request: Union[compute.PatchFirewallRequest, dict] = None,
+        request: Optional[Union[compute.PatchFirewallRequest, dict]] = None,
         *,
-        project: str = None,
-        firewall: str = None,
-        firewall_resource: compute.Firewall = None,
+        project: Optional[str] = None,
+        firewall: Optional[str] = None,
+        firewall_resource: Optional[compute.Firewall] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Updates the specified firewall rule with the data
@@ -1075,13 +1089,13 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
 
     def patch(
         self,
-        request: Union[compute.PatchFirewallRequest, dict] = None,
+        request: Optional[Union[compute.PatchFirewallRequest, dict]] = None,
         *,
-        project: str = None,
-        firewall: str = None,
-        firewall_resource: compute.Firewall = None,
+        project: Optional[str] = None,
+        firewall: Optional[str] = None,
+        firewall_resource: Optional[compute.Firewall] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Updates the specified firewall rule with the data
@@ -1197,13 +1211,13 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
 
     def update_unary(
         self,
-        request: Union[compute.UpdateFirewallRequest, dict] = None,
+        request: Optional[Union[compute.UpdateFirewallRequest, dict]] = None,
         *,
-        project: str = None,
-        firewall: str = None,
-        firewall_resource: compute.Firewall = None,
+        project: Optional[str] = None,
+        firewall: Optional[str] = None,
+        firewall_resource: Optional[compute.Firewall] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Updates the specified firewall rule with the data
@@ -1297,13 +1311,13 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
 
     def update(
         self,
-        request: Union[compute.UpdateFirewallRequest, dict] = None,
+        request: Optional[Union[compute.UpdateFirewallRequest, dict]] = None,
         *,
-        project: str = None,
-        firewall: str = None,
-        firewall_resource: compute.Firewall = None,
+        project: Optional[str] = None,
+        firewall: Optional[str] = None,
+        firewall_resource: Optional[compute.Firewall] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Updates the specified firewall rule with the data
@@ -1433,14 +1447,9 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("FirewallsClient",)
