@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.global_addresses import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import GlobalAddressesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, GlobalAddressesTransport
 from .transports.rest import GlobalAddressesRestTransport
 
 
@@ -58,7 +71,7 @@ class GlobalAddressesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[GlobalAddressesTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class GlobalAddressesClient(metaclass=GlobalAddressesClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class GlobalAddressesClient(metaclass=GlobalAddressesClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, GlobalAddressesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, GlobalAddressesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the global addresses client.
@@ -329,7 +342,7 @@ class GlobalAddressesClient(metaclass=GlobalAddressesClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class GlobalAddressesClient(metaclass=GlobalAddressesClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,12 +425,12 @@ class GlobalAddressesClient(metaclass=GlobalAddressesClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteGlobalAddressRequest, dict] = None,
+        request: Optional[Union[compute.DeleteGlobalAddressRequest, dict]] = None,
         *,
-        project: str = None,
-        address: str = None,
+        project: Optional[str] = None,
+        address: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified address resource.
@@ -501,12 +515,12 @@ class GlobalAddressesClient(metaclass=GlobalAddressesClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteGlobalAddressRequest, dict] = None,
+        request: Optional[Union[compute.DeleteGlobalAddressRequest, dict]] = None,
         *,
-        project: str = None,
-        address: str = None,
+        project: Optional[str] = None,
+        address: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified address resource.
@@ -615,12 +629,12 @@ class GlobalAddressesClient(metaclass=GlobalAddressesClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetGlobalAddressRequest, dict] = None,
+        request: Optional[Union[compute.GetGlobalAddressRequest, dict]] = None,
         *,
-        project: str = None,
-        address: str = None,
+        project: Optional[str] = None,
+        address: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Address:
         r"""Returns the specified address resource. Gets a list
@@ -711,12 +725,12 @@ class GlobalAddressesClient(metaclass=GlobalAddressesClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertGlobalAddressRequest, dict] = None,
+        request: Optional[Union[compute.InsertGlobalAddressRequest, dict]] = None,
         *,
-        project: str = None,
-        address_resource: compute.Address = None,
+        project: Optional[str] = None,
+        address_resource: Optional[compute.Address] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates an address resource in the specified project
@@ -795,12 +809,12 @@ class GlobalAddressesClient(metaclass=GlobalAddressesClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertGlobalAddressRequest, dict] = None,
+        request: Optional[Union[compute.InsertGlobalAddressRequest, dict]] = None,
         *,
-        project: str = None,
-        address_resource: compute.Address = None,
+        project: Optional[str] = None,
+        address_resource: Optional[compute.Address] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates an address resource in the specified project
@@ -903,11 +917,11 @@ class GlobalAddressesClient(metaclass=GlobalAddressesClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListGlobalAddressesRequest, dict] = None,
+        request: Optional[Union[compute.ListGlobalAddressesRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves a list of global addresses.
@@ -989,13 +1003,15 @@ class GlobalAddressesClient(metaclass=GlobalAddressesClientMeta):
 
     def set_labels_unary(
         self,
-        request: Union[compute.SetLabelsGlobalAddressRequest, dict] = None,
+        request: Optional[Union[compute.SetLabelsGlobalAddressRequest, dict]] = None,
         *,
-        project: str = None,
-        resource: str = None,
-        global_set_labels_request_resource: compute.GlobalSetLabelsRequest = None,
+        project: Optional[str] = None,
+        resource: Optional[str] = None,
+        global_set_labels_request_resource: Optional[
+            compute.GlobalSetLabelsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Sets the labels on a GlobalAddress. To learn more
@@ -1092,13 +1108,15 @@ class GlobalAddressesClient(metaclass=GlobalAddressesClientMeta):
 
     def set_labels(
         self,
-        request: Union[compute.SetLabelsGlobalAddressRequest, dict] = None,
+        request: Optional[Union[compute.SetLabelsGlobalAddressRequest, dict]] = None,
         *,
-        project: str = None,
-        resource: str = None,
-        global_set_labels_request_resource: compute.GlobalSetLabelsRequest = None,
+        project: Optional[str] = None,
+        resource: Optional[str] = None,
+        global_set_labels_request_resource: Optional[
+            compute.GlobalSetLabelsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Sets the labels on a GlobalAddress. To learn more
@@ -1231,14 +1249,9 @@ class GlobalAddressesClient(metaclass=GlobalAddressesClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("GlobalAddressesClient",)
