@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.global_forwarding_rules import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import GlobalForwardingRulesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, GlobalForwardingRulesTransport
 from .transports.rest import GlobalForwardingRulesRestTransport
 
 
@@ -58,7 +71,7 @@ class GlobalForwardingRulesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[GlobalForwardingRulesTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, GlobalForwardingRulesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, GlobalForwardingRulesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the global forwarding rules client.
@@ -329,7 +342,7 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,12 +425,14 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteGlobalForwardingRuleRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteGlobalForwardingRuleRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        forwarding_rule: str = None,
+        project: Optional[str] = None,
+        forwarding_rule: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified GlobalForwardingRule resource.
@@ -501,12 +517,14 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteGlobalForwardingRuleRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteGlobalForwardingRuleRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        forwarding_rule: str = None,
+        project: Optional[str] = None,
+        forwarding_rule: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified GlobalForwardingRule resource.
@@ -615,12 +633,12 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetGlobalForwardingRuleRequest, dict] = None,
+        request: Optional[Union[compute.GetGlobalForwardingRuleRequest, dict]] = None,
         *,
-        project: str = None,
-        forwarding_rule: str = None,
+        project: Optional[str] = None,
+        forwarding_rule: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.ForwardingRule:
         r"""Returns the specified GlobalForwardingRule resource.
@@ -717,12 +735,14 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertGlobalForwardingRuleRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertGlobalForwardingRuleRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        forwarding_rule_resource: compute.ForwardingRule = None,
+        project: Optional[str] = None,
+        forwarding_rule_resource: Optional[compute.ForwardingRule] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a GlobalForwardingRule resource in the
@@ -802,12 +822,14 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertGlobalForwardingRuleRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertGlobalForwardingRuleRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        forwarding_rule_resource: compute.ForwardingRule = None,
+        project: Optional[str] = None,
+        forwarding_rule_resource: Optional[compute.ForwardingRule] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a GlobalForwardingRule resource in the
@@ -911,11 +933,11 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListGlobalForwardingRulesRequest, dict] = None,
+        request: Optional[Union[compute.ListGlobalForwardingRulesRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves a list of GlobalForwardingRule resources
@@ -999,13 +1021,13 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
 
     def patch_unary(
         self,
-        request: Union[compute.PatchGlobalForwardingRuleRequest, dict] = None,
+        request: Optional[Union[compute.PatchGlobalForwardingRuleRequest, dict]] = None,
         *,
-        project: str = None,
-        forwarding_rule: str = None,
-        forwarding_rule_resource: compute.ForwardingRule = None,
+        project: Optional[str] = None,
+        forwarding_rule: Optional[str] = None,
+        forwarding_rule_resource: Optional[compute.ForwardingRule] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Updates the specified forwarding rule with the data included in
@@ -1100,13 +1122,13 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
 
     def patch(
         self,
-        request: Union[compute.PatchGlobalForwardingRuleRequest, dict] = None,
+        request: Optional[Union[compute.PatchGlobalForwardingRuleRequest, dict]] = None,
         *,
-        project: str = None,
-        forwarding_rule: str = None,
-        forwarding_rule_resource: compute.ForwardingRule = None,
+        project: Optional[str] = None,
+        forwarding_rule: Optional[str] = None,
+        forwarding_rule_resource: Optional[compute.ForwardingRule] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Updates the specified forwarding rule with the data included in
@@ -1225,13 +1247,17 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
 
     def set_labels_unary(
         self,
-        request: Union[compute.SetLabelsGlobalForwardingRuleRequest, dict] = None,
+        request: Optional[
+            Union[compute.SetLabelsGlobalForwardingRuleRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        resource: str = None,
-        global_set_labels_request_resource: compute.GlobalSetLabelsRequest = None,
+        project: Optional[str] = None,
+        resource: Optional[str] = None,
+        global_set_labels_request_resource: Optional[
+            compute.GlobalSetLabelsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Sets the labels on the specified resource. To learn
@@ -1329,13 +1355,17 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
 
     def set_labels(
         self,
-        request: Union[compute.SetLabelsGlobalForwardingRuleRequest, dict] = None,
+        request: Optional[
+            Union[compute.SetLabelsGlobalForwardingRuleRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        resource: str = None,
-        global_set_labels_request_resource: compute.GlobalSetLabelsRequest = None,
+        project: Optional[str] = None,
+        resource: Optional[str] = None,
+        global_set_labels_request_resource: Optional[
+            compute.GlobalSetLabelsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Sets the labels on the specified resource. To learn
@@ -1457,13 +1487,15 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
 
     def set_target_unary(
         self,
-        request: Union[compute.SetTargetGlobalForwardingRuleRequest, dict] = None,
+        request: Optional[
+            Union[compute.SetTargetGlobalForwardingRuleRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        forwarding_rule: str = None,
-        target_reference_resource: compute.TargetReference = None,
+        project: Optional[str] = None,
+        forwarding_rule: Optional[str] = None,
+        target_reference_resource: Optional[compute.TargetReference] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Changes target URL for the GlobalForwardingRule
@@ -1559,13 +1591,15 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
 
     def set_target(
         self,
-        request: Union[compute.SetTargetGlobalForwardingRuleRequest, dict] = None,
+        request: Optional[
+            Union[compute.SetTargetGlobalForwardingRuleRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        forwarding_rule: str = None,
-        target_reference_resource: compute.TargetReference = None,
+        project: Optional[str] = None,
+        forwarding_rule: Optional[str] = None,
+        target_reference_resource: Optional[compute.TargetReference] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Changes target URL for the GlobalForwardingRule
@@ -1697,14 +1731,9 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("GlobalForwardingRulesClient",)
