@@ -16,19 +16,31 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
@@ -36,7 +48,8 @@ except AttributeError:  # pragma: NO COVER
 
 from google.cloud.compute_v1.services.global_operations import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import GlobalOperationsTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, GlobalOperationsTransport
 from .transports.rest import GlobalOperationsRestTransport
 
 
@@ -55,7 +68,7 @@ class GlobalOperationsClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[GlobalOperationsTransport]:
         """Returns an appropriate transport class.
 
@@ -253,7 +266,7 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -308,8 +321,8 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, GlobalOperationsTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, GlobalOperationsTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the global operations client.
@@ -326,7 +339,7 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -356,6 +369,7 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -408,11 +422,13 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
 
     def aggregated_list(
         self,
-        request: Union[compute.AggregatedListGlobalOperationsRequest, dict] = None,
+        request: Optional[
+            Union[compute.AggregatedListGlobalOperationsRequest, dict]
+        ] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Retrieves an aggregated list of all operations.
@@ -493,12 +509,12 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteGlobalOperationRequest, dict] = None,
+        request: Optional[Union[compute.DeleteGlobalOperationRequest, dict]] = None,
         *,
-        project: str = None,
-        operation: str = None,
+        project: Optional[str] = None,
+        operation: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.DeleteGlobalOperationResponse:
         r"""Deletes the specified Operations resource.
@@ -584,12 +600,12 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetGlobalOperationRequest, dict] = None,
+        request: Optional[Union[compute.GetGlobalOperationRequest, dict]] = None,
         *,
-        project: str = None,
-        operation: str = None,
+        project: Optional[str] = None,
+        operation: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Retrieves the specified Operations resource.
@@ -687,11 +703,11 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListGlobalOperationsRequest, dict] = None,
+        request: Optional[Union[compute.ListGlobalOperationsRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves a list of Operation resources contained
@@ -775,12 +791,12 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
 
     def wait(
         self,
-        request: Union[compute.WaitGlobalOperationRequest, dict] = None,
+        request: Optional[Union[compute.WaitGlobalOperationRequest, dict]] = None,
         *,
-        project: str = None,
-        operation: str = None,
+        project: Optional[str] = None,
+        operation: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Waits for the specified Operation resource to return as ``DONE``
@@ -902,14 +918,9 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("GlobalOperationsClient",)
