@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.global_public_delegated_prefixes import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import GlobalPublicDelegatedPrefixesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, GlobalPublicDelegatedPrefixesTransport
 from .transports.rest import GlobalPublicDelegatedPrefixesRestTransport
 
 
@@ -58,7 +71,7 @@ class GlobalPublicDelegatedPrefixesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[GlobalPublicDelegatedPrefixesTransport]:
         """Returns an appropriate transport class.
 
@@ -258,7 +271,7 @@ class GlobalPublicDelegatedPrefixesClient(
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -313,8 +326,8 @@ class GlobalPublicDelegatedPrefixesClient(
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, GlobalPublicDelegatedPrefixesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, GlobalPublicDelegatedPrefixesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the global public delegated prefixes client.
@@ -331,7 +344,7 @@ class GlobalPublicDelegatedPrefixesClient(
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -361,6 +374,7 @@ class GlobalPublicDelegatedPrefixesClient(
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -413,12 +427,14 @@ class GlobalPublicDelegatedPrefixesClient(
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteGlobalPublicDelegatedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteGlobalPublicDelegatedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        public_delegated_prefix: str = None,
+        project: Optional[str] = None,
+        public_delegated_prefix: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified global PublicDelegatedPrefix.
@@ -503,12 +519,14 @@ class GlobalPublicDelegatedPrefixesClient(
 
     def delete(
         self,
-        request: Union[compute.DeleteGlobalPublicDelegatedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteGlobalPublicDelegatedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        public_delegated_prefix: str = None,
+        project: Optional[str] = None,
+        public_delegated_prefix: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified global PublicDelegatedPrefix.
@@ -617,12 +635,14 @@ class GlobalPublicDelegatedPrefixesClient(
 
     def get(
         self,
-        request: Union[compute.GetGlobalPublicDelegatedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.GetGlobalPublicDelegatedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        public_delegated_prefix: str = None,
+        project: Optional[str] = None,
+        public_delegated_prefix: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.PublicDelegatedPrefix:
         r"""Returns the specified global PublicDelegatedPrefix
@@ -715,12 +735,16 @@ class GlobalPublicDelegatedPrefixesClient(
 
     def insert_unary(
         self,
-        request: Union[compute.InsertGlobalPublicDelegatedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertGlobalPublicDelegatedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        public_delegated_prefix_resource: compute.PublicDelegatedPrefix = None,
+        project: Optional[str] = None,
+        public_delegated_prefix_resource: Optional[
+            compute.PublicDelegatedPrefix
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a global PublicDelegatedPrefix in the
@@ -802,12 +826,16 @@ class GlobalPublicDelegatedPrefixesClient(
 
     def insert(
         self,
-        request: Union[compute.InsertGlobalPublicDelegatedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertGlobalPublicDelegatedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        public_delegated_prefix_resource: compute.PublicDelegatedPrefix = None,
+        project: Optional[str] = None,
+        public_delegated_prefix_resource: Optional[
+            compute.PublicDelegatedPrefix
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a global PublicDelegatedPrefix in the
@@ -913,11 +941,13 @@ class GlobalPublicDelegatedPrefixesClient(
 
     def list(
         self,
-        request: Union[compute.ListGlobalPublicDelegatedPrefixesRequest, dict] = None,
+        request: Optional[
+            Union[compute.ListGlobalPublicDelegatedPrefixesRequest, dict]
+        ] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Lists the global PublicDelegatedPrefixes for a
@@ -999,13 +1029,17 @@ class GlobalPublicDelegatedPrefixesClient(
 
     def patch_unary(
         self,
-        request: Union[compute.PatchGlobalPublicDelegatedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.PatchGlobalPublicDelegatedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        public_delegated_prefix: str = None,
-        public_delegated_prefix_resource: compute.PublicDelegatedPrefix = None,
+        project: Optional[str] = None,
+        public_delegated_prefix: Optional[str] = None,
+        public_delegated_prefix_resource: Optional[
+            compute.PublicDelegatedPrefix
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Patches the specified global PublicDelegatedPrefix
@@ -1104,13 +1138,17 @@ class GlobalPublicDelegatedPrefixesClient(
 
     def patch(
         self,
-        request: Union[compute.PatchGlobalPublicDelegatedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.PatchGlobalPublicDelegatedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        public_delegated_prefix: str = None,
-        public_delegated_prefix_resource: compute.PublicDelegatedPrefix = None,
+        project: Optional[str] = None,
+        public_delegated_prefix: Optional[str] = None,
+        public_delegated_prefix_resource: Optional[
+            compute.PublicDelegatedPrefix
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Patches the specified global PublicDelegatedPrefix
@@ -1245,14 +1283,9 @@ class GlobalPublicDelegatedPrefixesClient(
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("GlobalPublicDelegatedPrefixesClient",)
