@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import HealthChecksTransport
-from .rest import HealthChecksRestTransport
-from .rest import HealthChecksRestInterceptor
-
+from .rest import HealthChecksRestInterceptor, HealthChecksRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[HealthChecksTransport]]
