@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import ImageFamilyViewsTransport
-from .rest import ImageFamilyViewsRestTransport
-from .rest import ImageFamilyViewsRestInterceptor
-
+from .rest import ImageFamilyViewsRestInterceptor, ImageFamilyViewsRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[ImageFamilyViewsTransport]]
