@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import ImagesTransport
-from .rest import ImagesRestTransport
-from .rest import ImagesRestInterceptor
-
+from .rest import ImagesRestInterceptor, ImagesRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[ImagesTransport]]
