@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import InstanceTemplatesTransport
-from .rest import InstanceTemplatesRestTransport
-from .rest import InstanceTemplatesRestInterceptor
-
+from .rest import InstanceTemplatesRestInterceptor, InstanceTemplatesRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[InstanceTemplatesTransport]]
