@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.interconnect_attachments import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import InterconnectAttachmentsTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, InterconnectAttachmentsTransport
 from .transports.rest import InterconnectAttachmentsRestTransport
 
 
@@ -58,7 +71,7 @@ class InterconnectAttachmentsClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[InterconnectAttachmentsTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, InterconnectAttachmentsTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, InterconnectAttachmentsTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the interconnect attachments client.
@@ -329,7 +342,7 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,13 +425,13 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
 
     def aggregated_list(
         self,
-        request: Union[
-            compute.AggregatedListInterconnectAttachmentsRequest, dict
+        request: Optional[
+            Union[compute.AggregatedListInterconnectAttachmentsRequest, dict]
         ] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Retrieves an aggregated list of interconnect
@@ -501,13 +515,15 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteInterconnectAttachmentRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteInterconnectAttachmentRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        interconnect_attachment: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        interconnect_attachment: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified interconnect attachment.
@@ -600,13 +616,15 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
 
     def delete(
         self,
-        request: Union[compute.DeleteInterconnectAttachmentRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteInterconnectAttachmentRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        interconnect_attachment: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        interconnect_attachment: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified interconnect attachment.
@@ -724,13 +742,13 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
 
     def get(
         self,
-        request: Union[compute.GetInterconnectAttachmentRequest, dict] = None,
+        request: Optional[Union[compute.GetInterconnectAttachmentRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        interconnect_attachment: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        interconnect_attachment: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.InterconnectAttachment:
         r"""Returns the specified interconnect attachment.
@@ -829,13 +847,17 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
 
     def insert_unary(
         self,
-        request: Union[compute.InsertInterconnectAttachmentRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertInterconnectAttachmentRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        interconnect_attachment_resource: compute.InterconnectAttachment = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        interconnect_attachment_resource: Optional[
+            compute.InterconnectAttachment
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates an InterconnectAttachment in the specified
@@ -928,13 +950,17 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
 
     def insert(
         self,
-        request: Union[compute.InsertInterconnectAttachmentRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertInterconnectAttachmentRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        interconnect_attachment_resource: compute.InterconnectAttachment = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        interconnect_attachment_resource: Optional[
+            compute.InterconnectAttachment
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates an InterconnectAttachment in the specified
@@ -1052,12 +1078,14 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
 
     def list(
         self,
-        request: Union[compute.ListInterconnectAttachmentsRequest, dict] = None,
+        request: Optional[
+            Union[compute.ListInterconnectAttachmentsRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves the list of interconnect attachments
@@ -1153,14 +1181,18 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
 
     def patch_unary(
         self,
-        request: Union[compute.PatchInterconnectAttachmentRequest, dict] = None,
+        request: Optional[
+            Union[compute.PatchInterconnectAttachmentRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        interconnect_attachment: str = None,
-        interconnect_attachment_resource: compute.InterconnectAttachment = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        interconnect_attachment: Optional[str] = None,
+        interconnect_attachment_resource: Optional[
+            compute.InterconnectAttachment
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Updates the specified interconnect attachment with
@@ -1269,14 +1301,18 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
 
     def patch(
         self,
-        request: Union[compute.PatchInterconnectAttachmentRequest, dict] = None,
+        request: Optional[
+            Union[compute.PatchInterconnectAttachmentRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        interconnect_attachment: str = None,
-        interconnect_attachment_resource: compute.InterconnectAttachment = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        interconnect_attachment: Optional[str] = None,
+        interconnect_attachment_resource: Optional[
+            compute.InterconnectAttachment
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Updates the specified interconnect attachment with
@@ -1410,14 +1446,18 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
 
     def set_labels_unary(
         self,
-        request: Union[compute.SetLabelsInterconnectAttachmentRequest, dict] = None,
+        request: Optional[
+            Union[compute.SetLabelsInterconnectAttachmentRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        resource: str = None,
-        region_set_labels_request_resource: compute.RegionSetLabelsRequest = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        resource: Optional[str] = None,
+        region_set_labels_request_resource: Optional[
+            compute.RegionSetLabelsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Sets the labels on an InterconnectAttachment. To
@@ -1523,14 +1563,18 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
 
     def set_labels(
         self,
-        request: Union[compute.SetLabelsInterconnectAttachmentRequest, dict] = None,
+        request: Optional[
+            Union[compute.SetLabelsInterconnectAttachmentRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        resource: str = None,
-        region_set_labels_request_resource: compute.RegionSetLabelsRequest = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        resource: Optional[str] = None,
+        region_set_labels_request_resource: Optional[
+            compute.RegionSetLabelsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Sets the labels on an InterconnectAttachment. To
@@ -1673,14 +1717,9 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("InterconnectAttachmentsClient",)
