@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.interconnects import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import InterconnectsTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, InterconnectsTransport
 from .transports.rest import InterconnectsRestTransport
 
 
@@ -56,7 +69,7 @@ class InterconnectsClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[InterconnectsTransport]:
         """Returns an appropriate transport class.
 
@@ -254,7 +267,7 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -309,8 +322,8 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, InterconnectsTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, InterconnectsTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the interconnects client.
@@ -327,7 +340,7 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -357,6 +370,7 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -409,15 +423,15 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteInterconnectRequest, dict] = None,
+        request: Optional[Union[compute.DeleteInterconnectRequest, dict]] = None,
         *,
-        project: str = None,
-        interconnect: str = None,
+        project: Optional[str] = None,
+        interconnect: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
-        r"""Deletes the specified interconnect.
+        r"""Deletes the specified Interconnect.
 
         Args:
             request (Union[google.cloud.compute_v1.types.DeleteInterconnectRequest, dict]):
@@ -497,15 +511,15 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteInterconnectRequest, dict] = None,
+        request: Optional[Union[compute.DeleteInterconnectRequest, dict]] = None,
         *,
-        project: str = None,
-        interconnect: str = None,
+        project: Optional[str] = None,
+        interconnect: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
-        r"""Deletes the specified interconnect.
+        r"""Deletes the specified Interconnect.
 
         Args:
             request (Union[google.cloud.compute_v1.types.DeleteInterconnectRequest, dict]):
@@ -609,16 +623,16 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetInterconnectRequest, dict] = None,
+        request: Optional[Union[compute.GetInterconnectRequest, dict]] = None,
         *,
-        project: str = None,
-        interconnect: str = None,
+        project: Optional[str] = None,
+        interconnect: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Interconnect:
-        r"""Returns the specified interconnect. Get a list of
-        available interconnects by making a list() request.
+        r"""Returns the specified Interconnect. Get a list of
+        available Interconnects by making a list() request.
 
         Args:
             request (Union[google.cloud.compute_v1.types.GetInterconnectRequest, dict]):
@@ -702,16 +716,18 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
 
     def get_diagnostics(
         self,
-        request: Union[compute.GetDiagnosticsInterconnectRequest, dict] = None,
+        request: Optional[
+            Union[compute.GetDiagnosticsInterconnectRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        interconnect: str = None,
+        project: Optional[str] = None,
+        interconnect: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.InterconnectsGetDiagnosticsResponse:
         r"""Returns the interconnectDiagnostics for the specified
-        interconnect.
+        Interconnect.
 
         Args:
             request (Union[google.cloud.compute_v1.types.GetDiagnosticsInterconnectRequest, dict]):
@@ -793,16 +809,16 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertInterconnectRequest, dict] = None,
+        request: Optional[Union[compute.InsertInterconnectRequest, dict]] = None,
         *,
-        project: str = None,
-        interconnect_resource: compute.Interconnect = None,
+        project: Optional[str] = None,
+        interconnect_resource: Optional[compute.Interconnect] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
-        r"""Creates a Interconnect in the specified project using
-        the data included in the request.
+        r"""Creates an Interconnect in the specified project
+        using the data included in the request.
 
         Args:
             request (Union[google.cloud.compute_v1.types.InsertInterconnectRequest, dict]):
@@ -877,16 +893,16 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertInterconnectRequest, dict] = None,
+        request: Optional[Union[compute.InsertInterconnectRequest, dict]] = None,
         *,
-        project: str = None,
-        interconnect_resource: compute.Interconnect = None,
+        project: Optional[str] = None,
+        interconnect_resource: Optional[compute.Interconnect] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
-        r"""Creates a Interconnect in the specified project using
-        the data included in the request.
+        r"""Creates an Interconnect in the specified project
+        using the data included in the request.
 
         Args:
             request (Union[google.cloud.compute_v1.types.InsertInterconnectRequest, dict]):
@@ -985,14 +1001,14 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListInterconnectsRequest, dict] = None,
+        request: Optional[Union[compute.ListInterconnectsRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
-        r"""Retrieves the list of interconnect available to the
+        r"""Retrieves the list of Interconnects available to the
         specified project.
 
         Args:
@@ -1073,16 +1089,16 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
 
     def patch_unary(
         self,
-        request: Union[compute.PatchInterconnectRequest, dict] = None,
+        request: Optional[Union[compute.PatchInterconnectRequest, dict]] = None,
         *,
-        project: str = None,
-        interconnect: str = None,
-        interconnect_resource: compute.Interconnect = None,
+        project: Optional[str] = None,
+        interconnect: Optional[str] = None,
+        interconnect_resource: Optional[compute.Interconnect] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
-        r"""Updates the specified interconnect with the data
+        r"""Updates the specified Interconnect with the data
         included in the request. This method supports PATCH
         semantics and uses the JSON merge patch format and
         processing rules.
@@ -1172,16 +1188,16 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
 
     def patch(
         self,
-        request: Union[compute.PatchInterconnectRequest, dict] = None,
+        request: Optional[Union[compute.PatchInterconnectRequest, dict]] = None,
         *,
-        project: str = None,
-        interconnect: str = None,
-        interconnect_resource: compute.Interconnect = None,
+        project: Optional[str] = None,
+        interconnect: Optional[str] = None,
+        interconnect_resource: Optional[compute.Interconnect] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
-        r"""Updates the specified interconnect with the data
+        r"""Updates the specified Interconnect with the data
         included in the request. This method supports PATCH
         semantics and uses the JSON merge patch format and
         processing rules.
@@ -1295,13 +1311,15 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
 
     def set_labels_unary(
         self,
-        request: Union[compute.SetLabelsInterconnectRequest, dict] = None,
+        request: Optional[Union[compute.SetLabelsInterconnectRequest, dict]] = None,
         *,
-        project: str = None,
-        resource: str = None,
-        global_set_labels_request_resource: compute.GlobalSetLabelsRequest = None,
+        project: Optional[str] = None,
+        resource: Optional[str] = None,
+        global_set_labels_request_resource: Optional[
+            compute.GlobalSetLabelsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Sets the labels on an Interconnect. To learn more
@@ -1398,13 +1416,15 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
 
     def set_labels(
         self,
-        request: Union[compute.SetLabelsInterconnectRequest, dict] = None,
+        request: Optional[Union[compute.SetLabelsInterconnectRequest, dict]] = None,
         *,
-        project: str = None,
-        resource: str = None,
-        global_set_labels_request_resource: compute.GlobalSetLabelsRequest = None,
+        project: Optional[str] = None,
+        resource: Optional[str] = None,
+        global_set_labels_request_resource: Optional[
+            compute.GlobalSetLabelsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Sets the labels on an Interconnect. To learn more
@@ -1537,14 +1557,9 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("InterconnectsClient",)
