@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import InterconnectsTransport
-from .rest import InterconnectsRestTransport
-from .rest import InterconnectsRestInterceptor
-
+from .rest import InterconnectsRestInterceptor, InterconnectsRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[InterconnectsTransport]]
