@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.machine_images import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import MachineImagesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, MachineImagesTransport
 from .transports.rest import MachineImagesRestTransport
 
 
@@ -56,7 +69,7 @@ class MachineImagesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[MachineImagesTransport]:
         """Returns an appropriate transport class.
 
@@ -254,7 +267,7 @@ class MachineImagesClient(metaclass=MachineImagesClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -309,8 +322,8 @@ class MachineImagesClient(metaclass=MachineImagesClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, MachineImagesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, MachineImagesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the machine images client.
@@ -327,7 +340,7 @@ class MachineImagesClient(metaclass=MachineImagesClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -357,6 +370,7 @@ class MachineImagesClient(metaclass=MachineImagesClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -409,12 +423,12 @@ class MachineImagesClient(metaclass=MachineImagesClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteMachineImageRequest, dict] = None,
+        request: Optional[Union[compute.DeleteMachineImageRequest, dict]] = None,
         *,
-        project: str = None,
-        machine_image: str = None,
+        project: Optional[str] = None,
+        machine_image: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified machine image. Deleting a
@@ -500,12 +514,12 @@ class MachineImagesClient(metaclass=MachineImagesClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteMachineImageRequest, dict] = None,
+        request: Optional[Union[compute.DeleteMachineImageRequest, dict]] = None,
         *,
-        project: str = None,
-        machine_image: str = None,
+        project: Optional[str] = None,
+        machine_image: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified machine image. Deleting a
@@ -615,12 +629,12 @@ class MachineImagesClient(metaclass=MachineImagesClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetMachineImageRequest, dict] = None,
+        request: Optional[Union[compute.GetMachineImageRequest, dict]] = None,
         *,
-        project: str = None,
-        machine_image: str = None,
+        project: Optional[str] = None,
+        machine_image: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.MachineImage:
         r"""Returns the specified machine image. Gets a list of
@@ -710,12 +724,12 @@ class MachineImagesClient(metaclass=MachineImagesClientMeta):
 
     def get_iam_policy(
         self,
-        request: Union[compute.GetIamPolicyMachineImageRequest, dict] = None,
+        request: Optional[Union[compute.GetIamPolicyMachineImageRequest, dict]] = None,
         *,
-        project: str = None,
-        resource: str = None,
+        project: Optional[str] = None,
+        resource: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Policy:
         r"""Gets the access control policy for a resource. May be
@@ -839,12 +853,12 @@ class MachineImagesClient(metaclass=MachineImagesClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertMachineImageRequest, dict] = None,
+        request: Optional[Union[compute.InsertMachineImageRequest, dict]] = None,
         *,
-        project: str = None,
-        machine_image_resource: compute.MachineImage = None,
+        project: Optional[str] = None,
+        machine_image_resource: Optional[compute.MachineImage] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a machine image in the specified project
@@ -927,12 +941,12 @@ class MachineImagesClient(metaclass=MachineImagesClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertMachineImageRequest, dict] = None,
+        request: Optional[Union[compute.InsertMachineImageRequest, dict]] = None,
         *,
-        project: str = None,
-        machine_image_resource: compute.MachineImage = None,
+        project: Optional[str] = None,
+        machine_image_resource: Optional[compute.MachineImage] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a machine image in the specified project
@@ -1039,11 +1053,11 @@ class MachineImagesClient(metaclass=MachineImagesClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListMachineImagesRequest, dict] = None,
+        request: Optional[Union[compute.ListMachineImagesRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves a list of machine images that are contained
@@ -1126,13 +1140,15 @@ class MachineImagesClient(metaclass=MachineImagesClientMeta):
 
     def set_iam_policy(
         self,
-        request: Union[compute.SetIamPolicyMachineImageRequest, dict] = None,
+        request: Optional[Union[compute.SetIamPolicyMachineImageRequest, dict]] = None,
         *,
-        project: str = None,
-        resource: str = None,
-        global_set_policy_request_resource: compute.GlobalSetPolicyRequest = None,
+        project: Optional[str] = None,
+        resource: Optional[str] = None,
+        global_set_policy_request_resource: Optional[
+            compute.GlobalSetPolicyRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Policy:
         r"""Sets the access control policy on the specified
@@ -1267,13 +1283,17 @@ class MachineImagesClient(metaclass=MachineImagesClientMeta):
 
     def test_iam_permissions(
         self,
-        request: Union[compute.TestIamPermissionsMachineImageRequest, dict] = None,
+        request: Optional[
+            Union[compute.TestIamPermissionsMachineImageRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        resource: str = None,
-        test_permissions_request_resource: compute.TestPermissionsRequest = None,
+        project: Optional[str] = None,
+        resource: Optional[str] = None,
+        test_permissions_request_resource: Optional[
+            compute.TestPermissionsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.TestPermissionsResponse:
         r"""Returns permissions that a caller has on the
@@ -1380,14 +1400,9 @@ class MachineImagesClient(metaclass=MachineImagesClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("MachineImagesClient",)
