@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.network_edge_security_services import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import NetworkEdgeSecurityServicesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, NetworkEdgeSecurityServicesTransport
 from .transports.rest import NetworkEdgeSecurityServicesRestTransport
 
 
@@ -58,7 +71,7 @@ class NetworkEdgeSecurityServicesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[NetworkEdgeSecurityServicesTransport]:
         """Returns an appropriate transport class.
 
@@ -258,7 +271,7 @@ class NetworkEdgeSecurityServicesClient(
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -313,8 +326,8 @@ class NetworkEdgeSecurityServicesClient(
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, NetworkEdgeSecurityServicesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, NetworkEdgeSecurityServicesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the network edge security services client.
@@ -331,7 +344,7 @@ class NetworkEdgeSecurityServicesClient(
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -361,6 +374,7 @@ class NetworkEdgeSecurityServicesClient(
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -413,13 +427,13 @@ class NetworkEdgeSecurityServicesClient(
 
     def aggregated_list(
         self,
-        request: Union[
-            compute.AggregatedListNetworkEdgeSecurityServicesRequest, dict
+        request: Optional[
+            Union[compute.AggregatedListNetworkEdgeSecurityServicesRequest, dict]
         ] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Retrieves the list of all NetworkEdgeSecurityService
@@ -505,13 +519,15 @@ class NetworkEdgeSecurityServicesClient(
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteNetworkEdgeSecurityServiceRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteNetworkEdgeSecurityServiceRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        network_edge_security_service: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        network_edge_security_service: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified service.
@@ -609,13 +625,15 @@ class NetworkEdgeSecurityServicesClient(
 
     def delete(
         self,
-        request: Union[compute.DeleteNetworkEdgeSecurityServiceRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteNetworkEdgeSecurityServiceRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        network_edge_security_service: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        network_edge_security_service: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified service.
@@ -738,13 +756,15 @@ class NetworkEdgeSecurityServicesClient(
 
     def get(
         self,
-        request: Union[compute.GetNetworkEdgeSecurityServiceRequest, dict] = None,
+        request: Optional[
+            Union[compute.GetNetworkEdgeSecurityServiceRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        network_edge_security_service: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        network_edge_security_service: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.NetworkEdgeSecurityService:
         r"""Gets a specified NetworkEdgeSecurityService.
@@ -842,13 +862,17 @@ class NetworkEdgeSecurityServicesClient(
 
     def insert_unary(
         self,
-        request: Union[compute.InsertNetworkEdgeSecurityServiceRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertNetworkEdgeSecurityServiceRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        network_edge_security_service_resource: compute.NetworkEdgeSecurityService = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        network_edge_security_service_resource: Optional[
+            compute.NetworkEdgeSecurityService
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a new service in the specified project using
@@ -945,13 +969,17 @@ class NetworkEdgeSecurityServicesClient(
 
     def insert(
         self,
-        request: Union[compute.InsertNetworkEdgeSecurityServiceRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertNetworkEdgeSecurityServiceRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        network_edge_security_service_resource: compute.NetworkEdgeSecurityService = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        network_edge_security_service_resource: Optional[
+            compute.NetworkEdgeSecurityService
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a new service in the specified project using
@@ -1073,14 +1101,18 @@ class NetworkEdgeSecurityServicesClient(
 
     def patch_unary(
         self,
-        request: Union[compute.PatchNetworkEdgeSecurityServiceRequest, dict] = None,
+        request: Optional[
+            Union[compute.PatchNetworkEdgeSecurityServiceRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        network_edge_security_service: str = None,
-        network_edge_security_service_resource: compute.NetworkEdgeSecurityService = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        network_edge_security_service: Optional[str] = None,
+        network_edge_security_service_resource: Optional[
+            compute.NetworkEdgeSecurityService
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Patches the specified policy with the data included
@@ -1195,14 +1227,18 @@ class NetworkEdgeSecurityServicesClient(
 
     def patch(
         self,
-        request: Union[compute.PatchNetworkEdgeSecurityServiceRequest, dict] = None,
+        request: Optional[
+            Union[compute.PatchNetworkEdgeSecurityServiceRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        network_edge_security_service: str = None,
-        network_edge_security_service_resource: compute.NetworkEdgeSecurityService = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        network_edge_security_service: Optional[str] = None,
+        network_edge_security_service_resource: Optional[
+            compute.NetworkEdgeSecurityService
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Patches the specified policy with the data included
@@ -1354,14 +1390,9 @@ class NetworkEdgeSecurityServicesClient(
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("NetworkEdgeSecurityServicesClient",)
