@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.network_endpoint_groups import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import NetworkEndpointGroupsTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, NetworkEndpointGroupsTransport
 from .transports.rest import NetworkEndpointGroupsRestTransport
 
 
@@ -58,7 +71,7 @@ class NetworkEndpointGroupsClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[NetworkEndpointGroupsTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, NetworkEndpointGroupsTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, NetworkEndpointGroupsTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the network endpoint groups client.
@@ -329,7 +342,7 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,11 +425,13 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
 
     def aggregated_list(
         self,
-        request: Union[compute.AggregatedListNetworkEndpointGroupsRequest, dict] = None,
+        request: Optional[
+            Union[compute.AggregatedListNetworkEndpointGroupsRequest, dict]
+        ] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Retrieves the list of network endpoint groups and
@@ -497,16 +513,18 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
 
     def attach_network_endpoints_unary(
         self,
-        request: Union[
-            compute.AttachNetworkEndpointsNetworkEndpointGroupRequest, dict
+        request: Optional[
+            Union[compute.AttachNetworkEndpointsNetworkEndpointGroupRequest, dict]
         ] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        network_endpoint_group: str = None,
-        network_endpoint_groups_attach_endpoints_request_resource: compute.NetworkEndpointGroupsAttachEndpointsRequest = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        network_endpoint_group: Optional[str] = None,
+        network_endpoint_groups_attach_endpoints_request_resource: Optional[
+            compute.NetworkEndpointGroupsAttachEndpointsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Attach a list of network endpoints to the specified
@@ -623,16 +641,18 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
 
     def attach_network_endpoints(
         self,
-        request: Union[
-            compute.AttachNetworkEndpointsNetworkEndpointGroupRequest, dict
+        request: Optional[
+            Union[compute.AttachNetworkEndpointsNetworkEndpointGroupRequest, dict]
         ] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        network_endpoint_group: str = None,
-        network_endpoint_groups_attach_endpoints_request_resource: compute.NetworkEndpointGroupsAttachEndpointsRequest = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        network_endpoint_group: Optional[str] = None,
+        network_endpoint_groups_attach_endpoints_request_resource: Optional[
+            compute.NetworkEndpointGroupsAttachEndpointsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Attach a list of network endpoints to the specified
@@ -774,13 +794,15 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteNetworkEndpointGroupRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteNetworkEndpointGroupRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        network_endpoint_group: str = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        network_endpoint_group: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified network endpoint group. The
@@ -881,13 +903,15 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteNetworkEndpointGroupRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteNetworkEndpointGroupRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        network_endpoint_group: str = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        network_endpoint_group: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified network endpoint group. The
@@ -1013,16 +1037,18 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
 
     def detach_network_endpoints_unary(
         self,
-        request: Union[
-            compute.DetachNetworkEndpointsNetworkEndpointGroupRequest, dict
+        request: Optional[
+            Union[compute.DetachNetworkEndpointsNetworkEndpointGroupRequest, dict]
         ] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        network_endpoint_group: str = None,
-        network_endpoint_groups_detach_endpoints_request_resource: compute.NetworkEndpointGroupsDetachEndpointsRequest = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        network_endpoint_group: Optional[str] = None,
+        network_endpoint_groups_detach_endpoints_request_resource: Optional[
+            compute.NetworkEndpointGroupsDetachEndpointsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Detach a list of network endpoints from the specified
@@ -1139,16 +1165,18 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
 
     def detach_network_endpoints(
         self,
-        request: Union[
-            compute.DetachNetworkEndpointsNetworkEndpointGroupRequest, dict
+        request: Optional[
+            Union[compute.DetachNetworkEndpointsNetworkEndpointGroupRequest, dict]
         ] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        network_endpoint_group: str = None,
-        network_endpoint_groups_detach_endpoints_request_resource: compute.NetworkEndpointGroupsDetachEndpointsRequest = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        network_endpoint_group: Optional[str] = None,
+        network_endpoint_groups_detach_endpoints_request_resource: Optional[
+            compute.NetworkEndpointGroupsDetachEndpointsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Detach a list of network endpoints from the specified
@@ -1290,13 +1318,13 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetNetworkEndpointGroupRequest, dict] = None,
+        request: Optional[Union[compute.GetNetworkEndpointGroupRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        network_endpoint_group: str = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        network_endpoint_group: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.NetworkEndpointGroup:
         r"""Returns the specified network endpoint group. Gets a
@@ -1403,13 +1431,15 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertNetworkEndpointGroupRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertNetworkEndpointGroupRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        network_endpoint_group_resource: compute.NetworkEndpointGroup = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        network_endpoint_group_resource: Optional[compute.NetworkEndpointGroup] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a network endpoint group in the specified
@@ -1506,13 +1536,15 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertNetworkEndpointGroupRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertNetworkEndpointGroupRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        network_endpoint_group_resource: compute.NetworkEndpointGroup = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        network_endpoint_group_resource: Optional[compute.NetworkEndpointGroup] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a network endpoint group in the specified
@@ -1634,12 +1666,12 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListNetworkEndpointGroupsRequest, dict] = None,
+        request: Optional[Union[compute.ListNetworkEndpointGroupsRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves the list of network endpoint groups that
@@ -1736,16 +1768,18 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
 
     def list_network_endpoints(
         self,
-        request: Union[
-            compute.ListNetworkEndpointsNetworkEndpointGroupsRequest, dict
+        request: Optional[
+            Union[compute.ListNetworkEndpointsNetworkEndpointGroupsRequest, dict]
         ] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        network_endpoint_group: str = None,
-        network_endpoint_groups_list_endpoints_request_resource: compute.NetworkEndpointGroupsListEndpointsRequest = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        network_endpoint_group: Optional[str] = None,
+        network_endpoint_groups_list_endpoints_request_resource: Optional[
+            compute.NetworkEndpointGroupsListEndpointsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListNetworkEndpointsPager:
         r"""Lists the network endpoints in the specified network
@@ -1872,16 +1906,18 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
 
     def test_iam_permissions(
         self,
-        request: Union[
-            compute.TestIamPermissionsNetworkEndpointGroupRequest, dict
+        request: Optional[
+            Union[compute.TestIamPermissionsNetworkEndpointGroupRequest, dict]
         ] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        resource: str = None,
-        test_permissions_request_resource: compute.TestPermissionsRequest = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        resource: Optional[str] = None,
+        test_permissions_request_resource: Optional[
+            compute.TestPermissionsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.TestPermissionsResponse:
         r"""Returns permissions that a caller has on the
@@ -2000,14 +2036,9 @@ class NetworkEndpointGroupsClient(metaclass=NetworkEndpointGroupsClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("NetworkEndpointGroupsClient",)
