@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.networks import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import NetworksTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, NetworksTransport
 from .transports.rest import NetworksRestTransport
 
 
@@ -56,7 +69,7 @@ class NetworksClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[NetworksTransport]:
         """Returns an appropriate transport class.
 
@@ -254,7 +267,7 @@ class NetworksClient(metaclass=NetworksClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -309,8 +322,8 @@ class NetworksClient(metaclass=NetworksClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, NetworksTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, NetworksTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the networks client.
@@ -327,7 +340,7 @@ class NetworksClient(metaclass=NetworksClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -357,6 +370,7 @@ class NetworksClient(metaclass=NetworksClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -409,13 +423,15 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def add_peering_unary(
         self,
-        request: Union[compute.AddPeeringNetworkRequest, dict] = None,
+        request: Optional[Union[compute.AddPeeringNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network: str = None,
-        networks_add_peering_request_resource: compute.NetworksAddPeeringRequest = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
+        networks_add_peering_request_resource: Optional[
+            compute.NetworksAddPeeringRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Adds a peering to the specified network.
@@ -511,13 +527,15 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def add_peering(
         self,
-        request: Union[compute.AddPeeringNetworkRequest, dict] = None,
+        request: Optional[Union[compute.AddPeeringNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network: str = None,
-        networks_add_peering_request_resource: compute.NetworksAddPeeringRequest = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
+        networks_add_peering_request_resource: Optional[
+            compute.NetworksAddPeeringRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Adds a peering to the specified network.
@@ -637,12 +655,12 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteNetworkRequest, dict] = None,
+        request: Optional[Union[compute.DeleteNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network: str = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified network.
@@ -724,12 +742,12 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteNetworkRequest, dict] = None,
+        request: Optional[Union[compute.DeleteNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network: str = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified network.
@@ -835,12 +853,12 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetNetworkRequest, dict] = None,
+        request: Optional[Union[compute.GetNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network: str = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Network:
         r"""Returns the specified network. Gets a list of
@@ -926,12 +944,14 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def get_effective_firewalls(
         self,
-        request: Union[compute.GetEffectiveFirewallsNetworkRequest, dict] = None,
+        request: Optional[
+            Union[compute.GetEffectiveFirewallsNetworkRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        network: str = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.NetworksGetEffectiveFirewallsResponse:
         r"""Returns the effective firewalls on a given network.
@@ -1012,12 +1032,12 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertNetworkRequest, dict] = None,
+        request: Optional[Union[compute.InsertNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network_resource: compute.Network = None,
+        project: Optional[str] = None,
+        network_resource: Optional[compute.Network] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a network in the specified project using the
@@ -1095,12 +1115,12 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertNetworkRequest, dict] = None,
+        request: Optional[Union[compute.InsertNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network_resource: compute.Network = None,
+        project: Optional[str] = None,
+        network_resource: Optional[compute.Network] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a network in the specified project using the
@@ -1202,11 +1222,11 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListNetworksRequest, dict] = None,
+        request: Optional[Union[compute.ListNetworksRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves the list of networks available to the
@@ -1288,12 +1308,12 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def list_peering_routes(
         self,
-        request: Union[compute.ListPeeringRoutesNetworksRequest, dict] = None,
+        request: Optional[Union[compute.ListPeeringRoutesNetworksRequest, dict]] = None,
         *,
-        project: str = None,
-        network: str = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPeeringRoutesPager:
         r"""Lists the peering routes exchanged over peering
@@ -1387,13 +1407,13 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def patch_unary(
         self,
-        request: Union[compute.PatchNetworkRequest, dict] = None,
+        request: Optional[Union[compute.PatchNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network: str = None,
-        network_resource: compute.Network = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
+        network_resource: Optional[compute.Network] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Patches the specified network with the data included
@@ -1484,13 +1504,13 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def patch(
         self,
-        request: Union[compute.PatchNetworkRequest, dict] = None,
+        request: Optional[Union[compute.PatchNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network: str = None,
-        network_resource: compute.Network = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
+        network_resource: Optional[compute.Network] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Patches the specified network with the data included
@@ -1605,13 +1625,15 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def remove_peering_unary(
         self,
-        request: Union[compute.RemovePeeringNetworkRequest, dict] = None,
+        request: Optional[Union[compute.RemovePeeringNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network: str = None,
-        networks_remove_peering_request_resource: compute.NetworksRemovePeeringRequest = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
+        networks_remove_peering_request_resource: Optional[
+            compute.NetworksRemovePeeringRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Removes a peering from the specified network.
@@ -1707,13 +1729,15 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def remove_peering(
         self,
-        request: Union[compute.RemovePeeringNetworkRequest, dict] = None,
+        request: Optional[Union[compute.RemovePeeringNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network: str = None,
-        networks_remove_peering_request_resource: compute.NetworksRemovePeeringRequest = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
+        networks_remove_peering_request_resource: Optional[
+            compute.NetworksRemovePeeringRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Removes a peering from the specified network.
@@ -1833,12 +1857,12 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def switch_to_custom_mode_unary(
         self,
-        request: Union[compute.SwitchToCustomModeNetworkRequest, dict] = None,
+        request: Optional[Union[compute.SwitchToCustomModeNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network: str = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Switches the network mode from auto subnet mode to
@@ -1922,12 +1946,12 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def switch_to_custom_mode(
         self,
-        request: Union[compute.SwitchToCustomModeNetworkRequest, dict] = None,
+        request: Optional[Union[compute.SwitchToCustomModeNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network: str = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Switches the network mode from auto subnet mode to
@@ -2035,13 +2059,15 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def update_peering_unary(
         self,
-        request: Union[compute.UpdatePeeringNetworkRequest, dict] = None,
+        request: Optional[Union[compute.UpdatePeeringNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network: str = None,
-        networks_update_peering_request_resource: compute.NetworksUpdatePeeringRequest = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
+        networks_update_peering_request_resource: Optional[
+            compute.NetworksUpdatePeeringRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Updates the specified network peering with the data included in
@@ -2140,13 +2166,15 @@ class NetworksClient(metaclass=NetworksClientMeta):
 
     def update_peering(
         self,
-        request: Union[compute.UpdatePeeringNetworkRequest, dict] = None,
+        request: Optional[Union[compute.UpdatePeeringNetworkRequest, dict]] = None,
         *,
-        project: str = None,
-        network: str = None,
-        networks_update_peering_request_resource: compute.NetworksUpdatePeeringRequest = None,
+        project: Optional[str] = None,
+        network: Optional[str] = None,
+        networks_update_peering_request_resource: Optional[
+            compute.NetworksUpdatePeeringRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Updates the specified network peering with the data included in
@@ -2281,14 +2309,9 @@ class NetworksClient(metaclass=NetworksClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("NetworksClient",)
