@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.node_templates import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import NodeTemplatesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, NodeTemplatesTransport
 from .transports.rest import NodeTemplatesRestTransport
 
 
@@ -56,7 +69,7 @@ class NodeTemplatesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[NodeTemplatesTransport]:
         """Returns an appropriate transport class.
 
@@ -254,7 +267,7 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -309,8 +322,8 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, NodeTemplatesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, NodeTemplatesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the node templates client.
@@ -327,7 +340,7 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -357,6 +370,7 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -409,11 +423,13 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
 
     def aggregated_list(
         self,
-        request: Union[compute.AggregatedListNodeTemplatesRequest, dict] = None,
+        request: Optional[
+            Union[compute.AggregatedListNodeTemplatesRequest, dict]
+        ] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Retrieves an aggregated list of node templates.
@@ -494,13 +510,13 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteNodeTemplateRequest, dict] = None,
+        request: Optional[Union[compute.DeleteNodeTemplateRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        node_template: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        node_template: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified NodeTemplate resource.
@@ -595,13 +611,13 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteNodeTemplateRequest, dict] = None,
+        request: Optional[Union[compute.DeleteNodeTemplateRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        node_template: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        node_template: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified NodeTemplate resource.
@@ -721,13 +737,13 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetNodeTemplateRequest, dict] = None,
+        request: Optional[Union[compute.GetNodeTemplateRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        node_template: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        node_template: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.NodeTemplate:
         r"""Returns the specified node template. Gets a list of
@@ -824,13 +840,13 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
 
     def get_iam_policy(
         self,
-        request: Union[compute.GetIamPolicyNodeTemplateRequest, dict] = None,
+        request: Optional[Union[compute.GetIamPolicyNodeTemplateRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        resource: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        resource: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Policy:
         r"""Gets the access control policy for a resource. May be
@@ -964,13 +980,13 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertNodeTemplateRequest, dict] = None,
+        request: Optional[Union[compute.InsertNodeTemplateRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        node_template_resource: compute.NodeTemplate = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        node_template_resource: Optional[compute.NodeTemplate] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a NodeTemplate resource in the specified
@@ -1063,13 +1079,13 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertNodeTemplateRequest, dict] = None,
+        request: Optional[Union[compute.InsertNodeTemplateRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        node_template_resource: compute.NodeTemplate = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        node_template_resource: Optional[compute.NodeTemplate] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a NodeTemplate resource in the specified
@@ -1187,12 +1203,12 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListNodeTemplatesRequest, dict] = None,
+        request: Optional[Union[compute.ListNodeTemplatesRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves a list of node templates available to the
@@ -1289,14 +1305,16 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
 
     def set_iam_policy(
         self,
-        request: Union[compute.SetIamPolicyNodeTemplateRequest, dict] = None,
+        request: Optional[Union[compute.SetIamPolicyNodeTemplateRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        resource: str = None,
-        region_set_policy_request_resource: compute.RegionSetPolicyRequest = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        resource: Optional[str] = None,
+        region_set_policy_request_resource: Optional[
+            compute.RegionSetPolicyRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Policy:
         r"""Sets the access control policy on the specified
@@ -1441,14 +1459,18 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
 
     def test_iam_permissions(
         self,
-        request: Union[compute.TestIamPermissionsNodeTemplateRequest, dict] = None,
+        request: Optional[
+            Union[compute.TestIamPermissionsNodeTemplateRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        resource: str = None,
-        test_permissions_request_resource: compute.TestPermissionsRequest = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        resource: Optional[str] = None,
+        test_permissions_request_resource: Optional[
+            compute.TestPermissionsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.TestPermissionsResponse:
         r"""Returns permissions that a caller has on the
@@ -1565,14 +1587,9 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("NodeTemplatesClient",)
