@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import NodeTypesTransport
-from .rest import NodeTypesRestTransport
-from .rest import NodeTypesRestInterceptor
-
+from .rest import NodeTypesRestInterceptor, NodeTypesRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[NodeTypesTransport]]
