@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.packet_mirrorings import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import PacketMirroringsTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, PacketMirroringsTransport
 from .transports.rest import PacketMirroringsRestTransport
 
 
@@ -58,7 +71,7 @@ class PacketMirroringsClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[PacketMirroringsTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, PacketMirroringsTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, PacketMirroringsTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the packet mirrorings client.
@@ -329,7 +342,7 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,11 +425,13 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
 
     def aggregated_list(
         self,
-        request: Union[compute.AggregatedListPacketMirroringsRequest, dict] = None,
+        request: Optional[
+            Union[compute.AggregatedListPacketMirroringsRequest, dict]
+        ] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Retrieves an aggregated list of packetMirrorings.
@@ -497,13 +513,13 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeletePacketMirroringRequest, dict] = None,
+        request: Optional[Union[compute.DeletePacketMirroringRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        packet_mirroring: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        packet_mirroring: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified PacketMirroring resource.
@@ -596,13 +612,13 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeletePacketMirroringRequest, dict] = None,
+        request: Optional[Union[compute.DeletePacketMirroringRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        packet_mirroring: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        packet_mirroring: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified PacketMirroring resource.
@@ -720,13 +736,13 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetPacketMirroringRequest, dict] = None,
+        request: Optional[Union[compute.GetPacketMirroringRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        packet_mirroring: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        packet_mirroring: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.PacketMirroring:
         r"""Returns the specified PacketMirroring resource.
@@ -827,13 +843,13 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertPacketMirroringRequest, dict] = None,
+        request: Optional[Union[compute.InsertPacketMirroringRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        packet_mirroring_resource: compute.PacketMirroring = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        packet_mirroring_resource: Optional[compute.PacketMirroring] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a PacketMirroring resource in the specified
@@ -925,13 +941,13 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertPacketMirroringRequest, dict] = None,
+        request: Optional[Union[compute.InsertPacketMirroringRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        packet_mirroring_resource: compute.PacketMirroring = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        packet_mirroring_resource: Optional[compute.PacketMirroring] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a PacketMirroring resource in the specified
@@ -1048,12 +1064,12 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListPacketMirroringsRequest, dict] = None,
+        request: Optional[Union[compute.ListPacketMirroringsRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves a list of PacketMirroring resources
@@ -1149,14 +1165,14 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
 
     def patch_unary(
         self,
-        request: Union[compute.PatchPacketMirroringRequest, dict] = None,
+        request: Optional[Union[compute.PatchPacketMirroringRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        packet_mirroring: str = None,
-        packet_mirroring_resource: compute.PacketMirroring = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        packet_mirroring: Optional[str] = None,
+        packet_mirroring_resource: Optional[compute.PacketMirroring] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Patches the specified PacketMirroring resource with
@@ -1261,14 +1277,14 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
 
     def patch(
         self,
-        request: Union[compute.PatchPacketMirroringRequest, dict] = None,
+        request: Optional[Union[compute.PatchPacketMirroringRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        packet_mirroring: str = None,
-        packet_mirroring_resource: compute.PacketMirroring = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        packet_mirroring: Optional[str] = None,
+        packet_mirroring_resource: Optional[compute.PacketMirroring] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Patches the specified PacketMirroring resource with
@@ -1398,14 +1414,18 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
 
     def test_iam_permissions(
         self,
-        request: Union[compute.TestIamPermissionsPacketMirroringRequest, dict] = None,
+        request: Optional[
+            Union[compute.TestIamPermissionsPacketMirroringRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        resource: str = None,
-        test_permissions_request_resource: compute.TestPermissionsRequest = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        resource: Optional[str] = None,
+        test_permissions_request_resource: Optional[
+            compute.TestPermissionsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.TestPermissionsResponse:
         r"""Returns permissions that a caller has on the
@@ -1522,14 +1542,9 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("PacketMirroringsClient",)
