@@ -14,25 +14,22 @@
 # limitations under the License.
 #
 
-from google.auth.transport.requests import AuthorizedSession  # type: ignore
-import json  # type: ignore
-import grpc  # type: ignore
-from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth import credentials as ga_credentials  # type: ignore
-from google.api_core import exceptions as core_exceptions
-from google.api_core import retry as retries
-from google.api_core import rest_helpers
-from google.api_core import rest_streaming
-from google.api_core import path_template
-from google.api_core import gapic_v1
-
-from google.protobuf import json_format
-from requests import __version__ as requests_version
 import dataclasses
+import json  # type: ignore
 import re
 from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
+from google.api_core import gapic_v1, path_template, rest_helpers, rest_streaming
+from google.api_core import exceptions as core_exceptions
+from google.api_core import retry as retries
+from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.transport.grpc import SslCredentials  # type: ignore
+from google.auth.transport.requests import AuthorizedSession  # type: ignore
+from google.protobuf import json_format
+import grpc  # type: ignore
+from requests import __version__ as requests_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
@@ -41,8 +38,8 @@ except AttributeError:  # pragma: NO COVER
 
 from google.cloud.compute_v1.types import compute
 
-from .base import ProjectsTransport, DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO
-
+from .base import DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO
+from .base import ProjectsTransport
 
 DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     gapic_version=BASE_DEFAULT_CLIENT_INFO.gapic_version,
@@ -66,96 +63,109 @@ class ProjectsRestInterceptor:
 
     .. code-block:: python
         class MyCustomProjectsInterceptor(ProjectsRestInterceptor):
-            def pre_disable_xpn_host(request, metadata):
+            def pre_disable_xpn_host(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_disable_xpn_host(response):
+            def post_disable_xpn_host(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_disable_xpn_resource(request, metadata):
+            def pre_disable_xpn_resource(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_disable_xpn_resource(response):
+            def post_disable_xpn_resource(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_enable_xpn_host(request, metadata):
+            def pre_enable_xpn_host(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_enable_xpn_host(response):
+            def post_enable_xpn_host(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_enable_xpn_resource(request, metadata):
+            def pre_enable_xpn_resource(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_enable_xpn_resource(response):
+            def post_enable_xpn_resource(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_get(request, metadata):
+            def pre_get(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get(response):
+            def post_get(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_get_xpn_host(request, metadata):
+            def pre_get_xpn_host(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get_xpn_host(response):
+            def post_get_xpn_host(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_get_xpn_resources(request, metadata):
+            def pre_get_xpn_resources(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get_xpn_resources(response):
+            def post_get_xpn_resources(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_list_xpn_hosts(request, metadata):
+            def pre_list_xpn_hosts(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_list_xpn_hosts(response):
+            def post_list_xpn_hosts(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_move_disk(request, metadata):
+            def pre_move_disk(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_move_disk(response):
+            def post_move_disk(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_move_instance(request, metadata):
+            def pre_move_instance(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_move_instance(response):
+            def post_move_instance(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_set_common_instance_metadata(request, metadata):
+            def pre_set_common_instance_metadata(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_set_common_instance_metadata(response):
+            def post_set_common_instance_metadata(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_set_default_network_tier(request, metadata):
+            def pre_set_default_network_tier(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_set_default_network_tier(response):
+            def post_set_default_network_tier(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_set_usage_export_bucket(request, metadata):
+            def pre_set_usage_export_bucket(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_set_usage_export_bucket(response):
+            def post_set_usage_export_bucket(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
         transport = ProjectsRestTransport(interceptor=MyCustomProjectsInterceptor())
         client = ProjectsClient(transport=transport)
@@ -476,10 +486,10 @@ class ProjectsRestTransport(ProjectsTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
-        scopes: Sequence[str] = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
@@ -571,7 +581,7 @@ class ProjectsRestTransport(ProjectsTransport):
             request: compute.DisableXpnHostProjectRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the disable xpn host method over HTTP.
@@ -675,7 +685,7 @@ class ProjectsRestTransport(ProjectsTransport):
             request: compute.DisableXpnResourceProjectRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the disable xpn resource method over HTTP.
@@ -788,7 +798,7 @@ class ProjectsRestTransport(ProjectsTransport):
             request: compute.EnableXpnHostProjectRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the enable xpn host method over HTTP.
@@ -890,7 +900,7 @@ class ProjectsRestTransport(ProjectsTransport):
             request: compute.EnableXpnResourceProjectRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the enable xpn resource method over HTTP.
@@ -1003,7 +1013,7 @@ class ProjectsRestTransport(ProjectsTransport):
             request: compute.GetProjectRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Project:
             r"""Call the get method over HTTP.
@@ -1094,7 +1104,7 @@ class ProjectsRestTransport(ProjectsTransport):
             request: compute.GetXpnHostProjectRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Project:
             r"""Call the get xpn host method over HTTP.
@@ -1186,7 +1196,7 @@ class ProjectsRestTransport(ProjectsTransport):
             request: compute.GetXpnResourcesProjectsRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.ProjectsGetXpnResources:
             r"""Call the get xpn resources method over HTTP.
@@ -1275,7 +1285,7 @@ class ProjectsRestTransport(ProjectsTransport):
             request: compute.ListXpnHostsProjectsRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.XpnHostList:
             r"""Call the list xpn hosts method over HTTP.
@@ -1371,7 +1381,7 @@ class ProjectsRestTransport(ProjectsTransport):
             request: compute.MoveDiskProjectRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the move disk method over HTTP.
@@ -1482,7 +1492,7 @@ class ProjectsRestTransport(ProjectsTransport):
             request: compute.MoveInstanceProjectRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the move instance method over HTTP.
@@ -1593,7 +1603,7 @@ class ProjectsRestTransport(ProjectsTransport):
             request: compute.SetCommonInstanceMetadataProjectRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the set common instance
@@ -1707,7 +1717,7 @@ class ProjectsRestTransport(ProjectsTransport):
             request: compute.SetDefaultNetworkTierProjectRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the set default network tier method over HTTP.
@@ -1820,7 +1830,7 @@ class ProjectsRestTransport(ProjectsTransport):
             request: compute.SetUsageExportBucketProjectRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the set usage export bucket method over HTTP.
