@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.public_advertised_prefixes import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import PublicAdvertisedPrefixesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, PublicAdvertisedPrefixesTransport
 from .transports.rest import PublicAdvertisedPrefixesRestTransport
 
 
@@ -58,7 +71,7 @@ class PublicAdvertisedPrefixesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[PublicAdvertisedPrefixesTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class PublicAdvertisedPrefixesClient(metaclass=PublicAdvertisedPrefixesClientMet
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class PublicAdvertisedPrefixesClient(metaclass=PublicAdvertisedPrefixesClientMet
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, PublicAdvertisedPrefixesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, PublicAdvertisedPrefixesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the public advertised prefixes client.
@@ -329,7 +342,7 @@ class PublicAdvertisedPrefixesClient(metaclass=PublicAdvertisedPrefixesClientMet
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class PublicAdvertisedPrefixesClient(metaclass=PublicAdvertisedPrefixesClientMet
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,12 +425,14 @@ class PublicAdvertisedPrefixesClient(metaclass=PublicAdvertisedPrefixesClientMet
 
     def delete_unary(
         self,
-        request: Union[compute.DeletePublicAdvertisedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeletePublicAdvertisedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        public_advertised_prefix: str = None,
+        project: Optional[str] = None,
+        public_advertised_prefix: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified PublicAdvertisedPrefix
@@ -501,12 +517,14 @@ class PublicAdvertisedPrefixesClient(metaclass=PublicAdvertisedPrefixesClientMet
 
     def delete(
         self,
-        request: Union[compute.DeletePublicAdvertisedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeletePublicAdvertisedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        public_advertised_prefix: str = None,
+        project: Optional[str] = None,
+        public_advertised_prefix: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified PublicAdvertisedPrefix
@@ -615,12 +633,14 @@ class PublicAdvertisedPrefixesClient(metaclass=PublicAdvertisedPrefixesClientMet
 
     def get(
         self,
-        request: Union[compute.GetPublicAdvertisedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.GetPublicAdvertisedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        public_advertised_prefix: str = None,
+        project: Optional[str] = None,
+        public_advertised_prefix: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.PublicAdvertisedPrefix:
         r"""Returns the specified PublicAdvertisedPrefix
@@ -710,12 +730,16 @@ class PublicAdvertisedPrefixesClient(metaclass=PublicAdvertisedPrefixesClientMet
 
     def insert_unary(
         self,
-        request: Union[compute.InsertPublicAdvertisedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertPublicAdvertisedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        public_advertised_prefix_resource: compute.PublicAdvertisedPrefix = None,
+        project: Optional[str] = None,
+        public_advertised_prefix_resource: Optional[
+            compute.PublicAdvertisedPrefix
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a PublicAdvertisedPrefix in the specified
@@ -797,12 +821,16 @@ class PublicAdvertisedPrefixesClient(metaclass=PublicAdvertisedPrefixesClientMet
 
     def insert(
         self,
-        request: Union[compute.InsertPublicAdvertisedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertPublicAdvertisedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        public_advertised_prefix_resource: compute.PublicAdvertisedPrefix = None,
+        project: Optional[str] = None,
+        public_advertised_prefix_resource: Optional[
+            compute.PublicAdvertisedPrefix
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a PublicAdvertisedPrefix in the specified
@@ -908,11 +936,13 @@ class PublicAdvertisedPrefixesClient(metaclass=PublicAdvertisedPrefixesClientMet
 
     def list(
         self,
-        request: Union[compute.ListPublicAdvertisedPrefixesRequest, dict] = None,
+        request: Optional[
+            Union[compute.ListPublicAdvertisedPrefixesRequest, dict]
+        ] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Lists the PublicAdvertisedPrefixes for a project.
@@ -993,13 +1023,17 @@ class PublicAdvertisedPrefixesClient(metaclass=PublicAdvertisedPrefixesClientMet
 
     def patch_unary(
         self,
-        request: Union[compute.PatchPublicAdvertisedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.PatchPublicAdvertisedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        public_advertised_prefix: str = None,
-        public_advertised_prefix_resource: compute.PublicAdvertisedPrefix = None,
+        project: Optional[str] = None,
+        public_advertised_prefix: Optional[str] = None,
+        public_advertised_prefix_resource: Optional[
+            compute.PublicAdvertisedPrefix
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Patches the specified Router resource with the data
@@ -1098,13 +1132,17 @@ class PublicAdvertisedPrefixesClient(metaclass=PublicAdvertisedPrefixesClientMet
 
     def patch(
         self,
-        request: Union[compute.PatchPublicAdvertisedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.PatchPublicAdvertisedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        public_advertised_prefix: str = None,
-        public_advertised_prefix_resource: compute.PublicAdvertisedPrefix = None,
+        project: Optional[str] = None,
+        public_advertised_prefix: Optional[str] = None,
+        public_advertised_prefix_resource: Optional[
+            compute.PublicAdvertisedPrefix
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Patches the specified Router resource with the data
@@ -1239,14 +1277,9 @@ class PublicAdvertisedPrefixesClient(metaclass=PublicAdvertisedPrefixesClientMet
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("PublicAdvertisedPrefixesClient",)
