@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.public_delegated_prefixes import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import PublicDelegatedPrefixesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, PublicDelegatedPrefixesTransport
 from .transports.rest import PublicDelegatedPrefixesRestTransport
 
 
@@ -58,7 +71,7 @@ class PublicDelegatedPrefixesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[PublicDelegatedPrefixesTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class PublicDelegatedPrefixesClient(metaclass=PublicDelegatedPrefixesClientMeta)
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class PublicDelegatedPrefixesClient(metaclass=PublicDelegatedPrefixesClientMeta)
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, PublicDelegatedPrefixesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, PublicDelegatedPrefixesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the public delegated prefixes client.
@@ -329,7 +342,7 @@ class PublicDelegatedPrefixesClient(metaclass=PublicDelegatedPrefixesClientMeta)
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class PublicDelegatedPrefixesClient(metaclass=PublicDelegatedPrefixesClientMeta)
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,13 +425,13 @@ class PublicDelegatedPrefixesClient(metaclass=PublicDelegatedPrefixesClientMeta)
 
     def aggregated_list(
         self,
-        request: Union[
-            compute.AggregatedListPublicDelegatedPrefixesRequest, dict
+        request: Optional[
+            Union[compute.AggregatedListPublicDelegatedPrefixesRequest, dict]
         ] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Lists all PublicDelegatedPrefix resources owned by
@@ -503,13 +517,15 @@ class PublicDelegatedPrefixesClient(metaclass=PublicDelegatedPrefixesClientMeta)
 
     def delete_unary(
         self,
-        request: Union[compute.DeletePublicDelegatedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeletePublicDelegatedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        public_delegated_prefix: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        public_delegated_prefix: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified PublicDelegatedPrefix in the
@@ -603,13 +619,15 @@ class PublicDelegatedPrefixesClient(metaclass=PublicDelegatedPrefixesClientMeta)
 
     def delete(
         self,
-        request: Union[compute.DeletePublicDelegatedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeletePublicDelegatedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        public_delegated_prefix: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        public_delegated_prefix: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified PublicDelegatedPrefix in the
@@ -728,13 +746,13 @@ class PublicDelegatedPrefixesClient(metaclass=PublicDelegatedPrefixesClientMeta)
 
     def get(
         self,
-        request: Union[compute.GetPublicDelegatedPrefixeRequest, dict] = None,
+        request: Optional[Union[compute.GetPublicDelegatedPrefixeRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        public_delegated_prefix: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        public_delegated_prefix: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.PublicDelegatedPrefix:
         r"""Returns the specified PublicDelegatedPrefix resource
@@ -835,13 +853,17 @@ class PublicDelegatedPrefixesClient(metaclass=PublicDelegatedPrefixesClientMeta)
 
     def insert_unary(
         self,
-        request: Union[compute.InsertPublicDelegatedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertPublicDelegatedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        public_delegated_prefix_resource: compute.PublicDelegatedPrefix = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        public_delegated_prefix_resource: Optional[
+            compute.PublicDelegatedPrefix
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a PublicDelegatedPrefix in the specified
@@ -935,13 +957,17 @@ class PublicDelegatedPrefixesClient(metaclass=PublicDelegatedPrefixesClientMeta)
 
     def insert(
         self,
-        request: Union[compute.InsertPublicDelegatedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertPublicDelegatedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        public_delegated_prefix_resource: compute.PublicDelegatedPrefix = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        public_delegated_prefix_resource: Optional[
+            compute.PublicDelegatedPrefix
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a PublicDelegatedPrefix in the specified
@@ -1060,12 +1086,14 @@ class PublicDelegatedPrefixesClient(metaclass=PublicDelegatedPrefixesClientMeta)
 
     def list(
         self,
-        request: Union[compute.ListPublicDelegatedPrefixesRequest, dict] = None,
+        request: Optional[
+            Union[compute.ListPublicDelegatedPrefixesRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Lists the PublicDelegatedPrefixes for a project in
@@ -1159,14 +1187,18 @@ class PublicDelegatedPrefixesClient(metaclass=PublicDelegatedPrefixesClientMeta)
 
     def patch_unary(
         self,
-        request: Union[compute.PatchPublicDelegatedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.PatchPublicDelegatedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        public_delegated_prefix: str = None,
-        public_delegated_prefix_resource: compute.PublicDelegatedPrefix = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        public_delegated_prefix: Optional[str] = None,
+        public_delegated_prefix_resource: Optional[
+            compute.PublicDelegatedPrefix
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Patches the specified PublicDelegatedPrefix resource
@@ -1273,14 +1305,18 @@ class PublicDelegatedPrefixesClient(metaclass=PublicDelegatedPrefixesClientMeta)
 
     def patch(
         self,
-        request: Union[compute.PatchPublicDelegatedPrefixeRequest, dict] = None,
+        request: Optional[
+            Union[compute.PatchPublicDelegatedPrefixeRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        public_delegated_prefix: str = None,
-        public_delegated_prefix_resource: compute.PublicDelegatedPrefix = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        public_delegated_prefix: Optional[str] = None,
+        public_delegated_prefix_resource: Optional[
+            compute.PublicDelegatedPrefix
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Patches the specified PublicDelegatedPrefix resource
@@ -1424,14 +1460,9 @@ class PublicDelegatedPrefixesClient(metaclass=PublicDelegatedPrefixesClientMeta)
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("PublicDelegatedPrefixesClient",)
