@@ -17,9 +17,10 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import PublicDelegatedPrefixesTransport
-from .rest import PublicDelegatedPrefixesRestTransport
-from .rest import PublicDelegatedPrefixesRestInterceptor
-
+from .rest import (
+    PublicDelegatedPrefixesRestInterceptor,
+    PublicDelegatedPrefixesRestTransport,
+)
 
 # Compile a registry of transports.
 _transport_registry = (
