@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import RegionDiskTypesTransport
-from .rest import RegionDiskTypesRestTransport
-from .rest import RegionDiskTypesRestInterceptor
-
+from .rest import RegionDiskTypesRestInterceptor, RegionDiskTypesRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[RegionDiskTypesTransport]]
