@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.region_health_check_services import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import RegionHealthCheckServicesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, RegionHealthCheckServicesTransport
 from .transports.rest import RegionHealthCheckServicesRestTransport
 
 
@@ -58,7 +71,7 @@ class RegionHealthCheckServicesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[RegionHealthCheckServicesTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, RegionHealthCheckServicesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, RegionHealthCheckServicesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the region health check services client.
@@ -329,7 +342,7 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,13 +425,15 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteRegionHealthCheckServiceRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteRegionHealthCheckServiceRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check_service: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check_service: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified regional HealthCheckService.
@@ -513,13 +529,15 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
 
     def delete(
         self,
-        request: Union[compute.DeleteRegionHealthCheckServiceRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteRegionHealthCheckServiceRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check_service: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check_service: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified regional HealthCheckService.
@@ -640,13 +658,15 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
 
     def get(
         self,
-        request: Union[compute.GetRegionHealthCheckServiceRequest, dict] = None,
+        request: Optional[
+            Union[compute.GetRegionHealthCheckServiceRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check_service: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check_service: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.HealthCheckService:
         r"""Returns the specified regional HealthCheckService
@@ -743,13 +763,15 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
 
     def insert_unary(
         self,
-        request: Union[compute.InsertRegionHealthCheckServiceRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertRegionHealthCheckServiceRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check_service_resource: compute.HealthCheckService = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check_service_resource: Optional[compute.HealthCheckService] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a regional HealthCheckService resource in the
@@ -843,13 +865,15 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
 
     def insert(
         self,
-        request: Union[compute.InsertRegionHealthCheckServiceRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertRegionHealthCheckServiceRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check_service_resource: compute.HealthCheckService = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check_service_resource: Optional[compute.HealthCheckService] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a regional HealthCheckService resource in the
@@ -968,12 +992,14 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
 
     def list(
         self,
-        request: Union[compute.ListRegionHealthCheckServicesRequest, dict] = None,
+        request: Optional[
+            Union[compute.ListRegionHealthCheckServicesRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Lists all the HealthCheckService resources that have
@@ -1070,14 +1096,16 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
 
     def patch_unary(
         self,
-        request: Union[compute.PatchRegionHealthCheckServiceRequest, dict] = None,
+        request: Optional[
+            Union[compute.PatchRegionHealthCheckServiceRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check_service: str = None,
-        health_check_service_resource: compute.HealthCheckService = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check_service: Optional[str] = None,
+        health_check_service_resource: Optional[compute.HealthCheckService] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Updates the specified regional HealthCheckService
@@ -1185,14 +1213,16 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
 
     def patch(
         self,
-        request: Union[compute.PatchRegionHealthCheckServiceRequest, dict] = None,
+        request: Optional[
+            Union[compute.PatchRegionHealthCheckServiceRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check_service: str = None,
-        health_check_service_resource: compute.HealthCheckService = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check_service: Optional[str] = None,
+        health_check_service_resource: Optional[compute.HealthCheckService] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Updates the specified regional HealthCheckService
@@ -1337,14 +1367,9 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("RegionHealthCheckServicesClient",)
