@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.region_health_checks import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import RegionHealthChecksTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, RegionHealthChecksTransport
 from .transports.rest import RegionHealthChecksRestTransport
 
 
@@ -58,7 +71,7 @@ class RegionHealthChecksClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[RegionHealthChecksTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, RegionHealthChecksTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, RegionHealthChecksTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the region health checks client.
@@ -329,7 +342,7 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,13 +425,13 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteRegionHealthCheckRequest, dict] = None,
+        request: Optional[Union[compute.DeleteRegionHealthCheckRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified HealthCheck resource.
@@ -512,13 +526,13 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteRegionHealthCheckRequest, dict] = None,
+        request: Optional[Union[compute.DeleteRegionHealthCheckRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified HealthCheck resource.
@@ -638,13 +652,13 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetRegionHealthCheckRequest, dict] = None,
+        request: Optional[Union[compute.GetRegionHealthCheckRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.HealthCheck:
         r"""Returns the specified HealthCheck resource. Gets a
@@ -758,13 +772,13 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertRegionHealthCheckRequest, dict] = None,
+        request: Optional[Union[compute.InsertRegionHealthCheckRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check_resource: compute.HealthCheck = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check_resource: Optional[compute.HealthCheck] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a HealthCheck resource in the specified
@@ -857,13 +871,13 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertRegionHealthCheckRequest, dict] = None,
+        request: Optional[Union[compute.InsertRegionHealthCheckRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check_resource: compute.HealthCheck = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check_resource: Optional[compute.HealthCheck] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a HealthCheck resource in the specified
@@ -981,12 +995,12 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListRegionHealthChecksRequest, dict] = None,
+        request: Optional[Union[compute.ListRegionHealthChecksRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves the list of HealthCheck resources available
@@ -1084,14 +1098,14 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
 
     def patch_unary(
         self,
-        request: Union[compute.PatchRegionHealthCheckRequest, dict] = None,
+        request: Optional[Union[compute.PatchRegionHealthCheckRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check: str = None,
-        health_check_resource: compute.HealthCheck = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check: Optional[str] = None,
+        health_check_resource: Optional[compute.HealthCheck] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Updates a HealthCheck resource in the specified
@@ -1198,14 +1212,14 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
 
     def patch(
         self,
-        request: Union[compute.PatchRegionHealthCheckRequest, dict] = None,
+        request: Optional[Union[compute.PatchRegionHealthCheckRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check: str = None,
-        health_check_resource: compute.HealthCheck = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check: Optional[str] = None,
+        health_check_resource: Optional[compute.HealthCheck] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Updates a HealthCheck resource in the specified
@@ -1337,14 +1351,14 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
 
     def update_unary(
         self,
-        request: Union[compute.UpdateRegionHealthCheckRequest, dict] = None,
+        request: Optional[Union[compute.UpdateRegionHealthCheckRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check: str = None,
-        health_check_resource: compute.HealthCheck = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check: Optional[str] = None,
+        health_check_resource: Optional[compute.HealthCheck] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Updates a HealthCheck resource in the specified
@@ -1449,14 +1463,14 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
 
     def update(
         self,
-        request: Union[compute.UpdateRegionHealthCheckRequest, dict] = None,
+        request: Optional[Union[compute.UpdateRegionHealthCheckRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        health_check: str = None,
-        health_check_resource: compute.HealthCheck = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        health_check: Optional[str] = None,
+        health_check_resource: Optional[compute.HealthCheck] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Updates a HealthCheck resource in the specified
@@ -1598,14 +1612,9 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("RegionHealthChecksClient",)
