@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.region_network_endpoint_groups import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import RegionNetworkEndpointGroupsTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, RegionNetworkEndpointGroupsTransport
 from .transports.rest import RegionNetworkEndpointGroupsRestTransport
 
 
@@ -58,7 +71,7 @@ class RegionNetworkEndpointGroupsClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[RegionNetworkEndpointGroupsTransport]:
         """Returns an appropriate transport class.
 
@@ -258,7 +271,7 @@ class RegionNetworkEndpointGroupsClient(
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -313,8 +326,8 @@ class RegionNetworkEndpointGroupsClient(
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, RegionNetworkEndpointGroupsTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, RegionNetworkEndpointGroupsTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the region network endpoint groups client.
@@ -331,7 +344,7 @@ class RegionNetworkEndpointGroupsClient(
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -361,6 +374,7 @@ class RegionNetworkEndpointGroupsClient(
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -413,13 +427,15 @@ class RegionNetworkEndpointGroupsClient(
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteRegionNetworkEndpointGroupRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteRegionNetworkEndpointGroupRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        network_endpoint_group: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        network_endpoint_group: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified network endpoint group. Note
@@ -518,13 +534,15 @@ class RegionNetworkEndpointGroupsClient(
 
     def delete(
         self,
-        request: Union[compute.DeleteRegionNetworkEndpointGroupRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteRegionNetworkEndpointGroupRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        network_endpoint_group: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        network_endpoint_group: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified network endpoint group. Note
@@ -648,13 +666,15 @@ class RegionNetworkEndpointGroupsClient(
 
     def get(
         self,
-        request: Union[compute.GetRegionNetworkEndpointGroupRequest, dict] = None,
+        request: Optional[
+            Union[compute.GetRegionNetworkEndpointGroupRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        network_endpoint_group: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        network_endpoint_group: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.NetworkEndpointGroup:
         r"""Returns the specified network endpoint group. Gets a
@@ -761,13 +781,15 @@ class RegionNetworkEndpointGroupsClient(
 
     def insert_unary(
         self,
-        request: Union[compute.InsertRegionNetworkEndpointGroupRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertRegionNetworkEndpointGroupRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        network_endpoint_group_resource: compute.NetworkEndpointGroup = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        network_endpoint_group_resource: Optional[compute.NetworkEndpointGroup] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a network endpoint group in the specified
@@ -864,13 +886,15 @@ class RegionNetworkEndpointGroupsClient(
 
     def insert(
         self,
-        request: Union[compute.InsertRegionNetworkEndpointGroupRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertRegionNetworkEndpointGroupRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        network_endpoint_group_resource: compute.NetworkEndpointGroup = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        network_endpoint_group_resource: Optional[compute.NetworkEndpointGroup] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a network endpoint group in the specified
@@ -992,12 +1016,14 @@ class RegionNetworkEndpointGroupsClient(
 
     def list(
         self,
-        request: Union[compute.ListRegionNetworkEndpointGroupsRequest, dict] = None,
+        request: Optional[
+            Union[compute.ListRegionNetworkEndpointGroupsRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves the list of regional network endpoint
@@ -1107,14 +1133,9 @@ class RegionNetworkEndpointGroupsClient(
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("RegionNetworkEndpointGroupsClient",)
