@@ -17,9 +17,10 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import RegionNotificationEndpointsTransport
-from .rest import RegionNotificationEndpointsRestTransport
-from .rest import RegionNotificationEndpointsRestInterceptor
-
+from .rest import (
+    RegionNotificationEndpointsRestInterceptor,
+    RegionNotificationEndpointsRestTransport,
+)
 
 # Compile a registry of transports.
 _transport_registry = (
