@@ -16,19 +16,31 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
@@ -36,7 +48,8 @@ except AttributeError:  # pragma: NO COVER
 
 from google.cloud.compute_v1.services.region_operations import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import RegionOperationsTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, RegionOperationsTransport
 from .transports.rest import RegionOperationsRestTransport
 
 
@@ -55,7 +68,7 @@ class RegionOperationsClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[RegionOperationsTransport]:
         """Returns an appropriate transport class.
 
@@ -253,7 +266,7 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -308,8 +321,8 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, RegionOperationsTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, RegionOperationsTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the region operations client.
@@ -326,7 +339,7 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -356,6 +369,7 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -408,13 +422,13 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteRegionOperationRequest, dict] = None,
+        request: Optional[Union[compute.DeleteRegionOperationRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        operation: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        operation: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.DeleteRegionOperationResponse:
         r"""Deletes the specified region-specific Operations
@@ -509,13 +523,13 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetRegionOperationRequest, dict] = None,
+        request: Optional[Union[compute.GetRegionOperationRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        operation: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        operation: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Retrieves the specified region-specific Operations
@@ -622,12 +636,12 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListRegionOperationsRequest, dict] = None,
+        request: Optional[Union[compute.ListRegionOperationsRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves a list of Operation resources contained
@@ -723,13 +737,13 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
 
     def wait(
         self,
-        request: Union[compute.WaitRegionOperationRequest, dict] = None,
+        request: Optional[Union[compute.WaitRegionOperationRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        operation: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        operation: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Waits for the specified Operation resource to return as ``DONE``
@@ -859,14 +873,9 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("RegionOperationsClient",)
