@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import RegionOperationsTransport
-from .rest import RegionOperationsRestTransport
-from .rest import RegionOperationsRestInterceptor
-
+from .rest import RegionOperationsRestInterceptor, RegionOperationsRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[RegionOperationsTransport]]
