@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.region_security_policies import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import RegionSecurityPoliciesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, RegionSecurityPoliciesTransport
 from .transports.rest import RegionSecurityPoliciesRestTransport
 
 
@@ -58,7 +71,7 @@ class RegionSecurityPoliciesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[RegionSecurityPoliciesTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class RegionSecurityPoliciesClient(metaclass=RegionSecurityPoliciesClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class RegionSecurityPoliciesClient(metaclass=RegionSecurityPoliciesClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, RegionSecurityPoliciesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, RegionSecurityPoliciesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the region security policies client.
@@ -329,7 +342,7 @@ class RegionSecurityPoliciesClient(metaclass=RegionSecurityPoliciesClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class RegionSecurityPoliciesClient(metaclass=RegionSecurityPoliciesClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,13 +425,15 @@ class RegionSecurityPoliciesClient(metaclass=RegionSecurityPoliciesClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteRegionSecurityPolicyRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteRegionSecurityPolicyRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        security_policy: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        security_policy: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified policy.
@@ -512,13 +528,15 @@ class RegionSecurityPoliciesClient(metaclass=RegionSecurityPoliciesClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteRegionSecurityPolicyRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteRegionSecurityPolicyRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        security_policy: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        security_policy: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified policy.
@@ -638,13 +656,13 @@ class RegionSecurityPoliciesClient(metaclass=RegionSecurityPoliciesClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetRegionSecurityPolicyRequest, dict] = None,
+        request: Optional[Union[compute.GetRegionSecurityPolicyRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        security_policy: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        security_policy: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.SecurityPolicy:
         r"""List all of the ordered rules present in a single
@@ -742,13 +760,15 @@ class RegionSecurityPoliciesClient(metaclass=RegionSecurityPoliciesClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertRegionSecurityPolicyRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertRegionSecurityPolicyRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        security_policy_resource: compute.SecurityPolicy = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        security_policy_resource: Optional[compute.SecurityPolicy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a new policy in the specified project using
@@ -841,13 +861,15 @@ class RegionSecurityPoliciesClient(metaclass=RegionSecurityPoliciesClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertRegionSecurityPolicyRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertRegionSecurityPolicyRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        security_policy_resource: compute.SecurityPolicy = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        security_policy_resource: Optional[compute.SecurityPolicy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a new policy in the specified project using
@@ -965,12 +987,14 @@ class RegionSecurityPoliciesClient(metaclass=RegionSecurityPoliciesClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListRegionSecurityPoliciesRequest, dict] = None,
+        request: Optional[
+            Union[compute.ListRegionSecurityPoliciesRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""List all the policies that have been configured for
@@ -1066,18 +1090,22 @@ class RegionSecurityPoliciesClient(metaclass=RegionSecurityPoliciesClientMeta):
 
     def patch_unary(
         self,
-        request: Union[compute.PatchRegionSecurityPolicyRequest, dict] = None,
+        request: Optional[Union[compute.PatchRegionSecurityPolicyRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        security_policy: str = None,
-        security_policy_resource: compute.SecurityPolicy = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        security_policy: Optional[str] = None,
+        security_policy_resource: Optional[compute.SecurityPolicy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Patches the specified policy with the data included
-        in the request.
+        in the request. To clear fields in the rule, leave the
+        fields empty and specify them in the updateMask. This
+        cannot be used to be update the rules in the policy.
+        Please use the per rule methods like addRule, patchRule,
+        and removeRule instead.
 
         Args:
             request (Union[google.cloud.compute_v1.types.PatchRegionSecurityPolicyRequest, dict]):
@@ -1178,18 +1206,22 @@ class RegionSecurityPoliciesClient(metaclass=RegionSecurityPoliciesClientMeta):
 
     def patch(
         self,
-        request: Union[compute.PatchRegionSecurityPolicyRequest, dict] = None,
+        request: Optional[Union[compute.PatchRegionSecurityPolicyRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        security_policy: str = None,
-        security_policy_resource: compute.SecurityPolicy = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        security_policy: Optional[str] = None,
+        security_policy_resource: Optional[compute.SecurityPolicy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Patches the specified policy with the data included
-        in the request.
+        in the request. To clear fields in the rule, leave the
+        fields empty and specify them in the updateMask. This
+        cannot be used to be update the rules in the policy.
+        Please use the per rule methods like addRule, patchRule,
+        and removeRule instead.
 
         Args:
             request (Union[google.cloud.compute_v1.types.PatchRegionSecurityPolicyRequest, dict]):
@@ -1327,14 +1359,9 @@ class RegionSecurityPoliciesClient(metaclass=RegionSecurityPoliciesClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("RegionSecurityPoliciesClient",)
