@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.region_ssl_certificates import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import RegionSslCertificatesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, RegionSslCertificatesTransport
 from .transports.rest import RegionSslCertificatesRestTransport
 
 
@@ -58,7 +71,7 @@ class RegionSslCertificatesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[RegionSslCertificatesTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class RegionSslCertificatesClient(metaclass=RegionSslCertificatesClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class RegionSslCertificatesClient(metaclass=RegionSslCertificatesClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, RegionSslCertificatesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, RegionSslCertificatesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the region ssl certificates client.
@@ -329,7 +342,7 @@ class RegionSslCertificatesClient(metaclass=RegionSslCertificatesClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class RegionSslCertificatesClient(metaclass=RegionSslCertificatesClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,13 +425,15 @@ class RegionSslCertificatesClient(metaclass=RegionSslCertificatesClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteRegionSslCertificateRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteRegionSslCertificateRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        ssl_certificate: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        ssl_certificate: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified SslCertificate resource in the
@@ -513,13 +529,15 @@ class RegionSslCertificatesClient(metaclass=RegionSslCertificatesClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteRegionSslCertificateRequest, dict] = None,
+        request: Optional[
+            Union[compute.DeleteRegionSslCertificateRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        ssl_certificate: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        ssl_certificate: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified SslCertificate resource in the
@@ -640,13 +658,13 @@ class RegionSslCertificatesClient(metaclass=RegionSslCertificatesClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetRegionSslCertificateRequest, dict] = None,
+        request: Optional[Union[compute.GetRegionSslCertificateRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        ssl_certificate: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        ssl_certificate: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.SslCertificate:
         r"""Returns the specified SslCertificate resource in the
@@ -757,13 +775,15 @@ class RegionSslCertificatesClient(metaclass=RegionSslCertificatesClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertRegionSslCertificateRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertRegionSslCertificateRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        ssl_certificate_resource: compute.SslCertificate = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        ssl_certificate_resource: Optional[compute.SslCertificate] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a SslCertificate resource in the specified
@@ -857,13 +877,15 @@ class RegionSslCertificatesClient(metaclass=RegionSslCertificatesClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertRegionSslCertificateRequest, dict] = None,
+        request: Optional[
+            Union[compute.InsertRegionSslCertificateRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        ssl_certificate_resource: compute.SslCertificate = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        ssl_certificate_resource: Optional[compute.SslCertificate] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a SslCertificate resource in the specified
@@ -982,12 +1004,12 @@ class RegionSslCertificatesClient(metaclass=RegionSslCertificatesClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListRegionSslCertificatesRequest, dict] = None,
+        request: Optional[Union[compute.ListRegionSslCertificatesRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves the list of SslCertificate resources
@@ -1098,14 +1120,9 @@ class RegionSslCertificatesClient(metaclass=RegionSslCertificatesClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("RegionSslCertificatesClient",)
