@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.reservations import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import ReservationsTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, ReservationsTransport
 from .transports.rest import ReservationsRestTransport
 
 
@@ -56,7 +69,7 @@ class ReservationsClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[ReservationsTransport]:
         """Returns an appropriate transport class.
 
@@ -254,7 +267,7 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -309,8 +322,8 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, ReservationsTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, ReservationsTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the reservations client.
@@ -327,7 +340,7 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -357,6 +370,7 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -409,11 +423,13 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
 
     def aggregated_list(
         self,
-        request: Union[compute.AggregatedListReservationsRequest, dict] = None,
+        request: Optional[
+            Union[compute.AggregatedListReservationsRequest, dict]
+        ] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Retrieves an aggregated list of reservations.
@@ -495,13 +511,13 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteReservationRequest, dict] = None,
+        request: Optional[Union[compute.DeleteReservationRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        reservation: str = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        reservation: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified reservation.
@@ -592,13 +608,13 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteReservationRequest, dict] = None,
+        request: Optional[Union[compute.DeleteReservationRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        reservation: str = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        reservation: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified reservation.
@@ -714,13 +730,13 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetReservationRequest, dict] = None,
+        request: Optional[Union[compute.GetReservationRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        reservation: str = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        reservation: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Reservation:
         r"""Retrieves information about the specified
@@ -816,13 +832,13 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
 
     def get_iam_policy(
         self,
-        request: Union[compute.GetIamPolicyReservationRequest, dict] = None,
+        request: Optional[Union[compute.GetIamPolicyReservationRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        resource: str = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        resource: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Policy:
         r"""Gets the access control policy for a resource. May be
@@ -956,13 +972,13 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertReservationRequest, dict] = None,
+        request: Optional[Union[compute.InsertReservationRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        reservation_resource: compute.Reservation = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        reservation_resource: Optional[compute.Reservation] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a new reservation. For more information, read
@@ -1053,13 +1069,13 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertReservationRequest, dict] = None,
+        request: Optional[Union[compute.InsertReservationRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        reservation_resource: compute.Reservation = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        reservation_resource: Optional[compute.Reservation] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a new reservation. For more information, read
@@ -1175,12 +1191,12 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListReservationsRequest, dict] = None,
+        request: Optional[Union[compute.ListReservationsRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""A list of all the reservations that have been
@@ -1274,14 +1290,16 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
 
     def resize_unary(
         self,
-        request: Union[compute.ResizeReservationRequest, dict] = None,
+        request: Optional[Union[compute.ResizeReservationRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        reservation: str = None,
-        reservations_resize_request_resource: compute.ReservationsResizeRequest = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        reservation: Optional[str] = None,
+        reservations_resize_request_resource: Optional[
+            compute.ReservationsResizeRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Resizes the reservation (applicable to standalone
@@ -1385,14 +1403,16 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
 
     def resize(
         self,
-        request: Union[compute.ResizeReservationRequest, dict] = None,
+        request: Optional[Union[compute.ResizeReservationRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        reservation: str = None,
-        reservations_resize_request_resource: compute.ReservationsResizeRequest = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        reservation: Optional[str] = None,
+        reservations_resize_request_resource: Optional[
+            compute.ReservationsResizeRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Resizes the reservation (applicable to standalone
@@ -1521,14 +1541,14 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
 
     def set_iam_policy(
         self,
-        request: Union[compute.SetIamPolicyReservationRequest, dict] = None,
+        request: Optional[Union[compute.SetIamPolicyReservationRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        resource: str = None,
-        zone_set_policy_request_resource: compute.ZoneSetPolicyRequest = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        resource: Optional[str] = None,
+        zone_set_policy_request_resource: Optional[compute.ZoneSetPolicyRequest] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Policy:
         r"""Sets the access control policy on the specified
@@ -1673,14 +1693,18 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
 
     def test_iam_permissions(
         self,
-        request: Union[compute.TestIamPermissionsReservationRequest, dict] = None,
+        request: Optional[
+            Union[compute.TestIamPermissionsReservationRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        resource: str = None,
-        test_permissions_request_resource: compute.TestPermissionsRequest = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        resource: Optional[str] = None,
+        test_permissions_request_resource: Optional[
+            compute.TestPermissionsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.TestPermissionsResponse:
         r"""Returns permissions that a caller has on the
@@ -1785,14 +1809,14 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
 
     def update_unary(
         self,
-        request: Union[compute.UpdateReservationRequest, dict] = None,
+        request: Optional[Union[compute.UpdateReservationRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        reservation: str = None,
-        reservation_resource: compute.Reservation = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        reservation: Optional[str] = None,
+        reservation_resource: Optional[compute.Reservation] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Update share settings of the reservation.
@@ -1890,14 +1914,14 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
 
     def update(
         self,
-        request: Union[compute.UpdateReservationRequest, dict] = None,
+        request: Optional[Union[compute.UpdateReservationRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        reservation: str = None,
-        reservation_resource: compute.Reservation = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        reservation: Optional[str] = None,
+        reservation_resource: Optional[compute.Reservation] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Update share settings of the reservation.
@@ -2032,14 +2056,9 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("ReservationsClient",)
