@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.routers import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import RoutersTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, RoutersTransport
 from .transports.rest import RoutersRestTransport
 
 
@@ -56,7 +69,7 @@ class RoutersClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[RoutersTransport]:
         """Returns an appropriate transport class.
 
@@ -254,7 +267,7 @@ class RoutersClient(metaclass=RoutersClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -309,8 +322,8 @@ class RoutersClient(metaclass=RoutersClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, RoutersTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, RoutersTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the routers client.
@@ -327,7 +340,7 @@ class RoutersClient(metaclass=RoutersClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -357,6 +370,7 @@ class RoutersClient(metaclass=RoutersClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -409,11 +423,11 @@ class RoutersClient(metaclass=RoutersClientMeta):
 
     def aggregated_list(
         self,
-        request: Union[compute.AggregatedListRoutersRequest, dict] = None,
+        request: Optional[Union[compute.AggregatedListRoutersRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Retrieves an aggregated list of routers.
@@ -495,13 +509,13 @@ class RoutersClient(metaclass=RoutersClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteRouterRequest, dict] = None,
+        request: Optional[Union[compute.DeleteRouterRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        router: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        router: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified Router resource.
@@ -593,13 +607,13 @@ class RoutersClient(metaclass=RoutersClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteRouterRequest, dict] = None,
+        request: Optional[Union[compute.DeleteRouterRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        router: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        router: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified Router resource.
@@ -716,13 +730,13 @@ class RoutersClient(metaclass=RoutersClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetRouterRequest, dict] = None,
+        request: Optional[Union[compute.GetRouterRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        router: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        router: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Router:
         r"""Returns the specified Router resource. Gets a list of
@@ -816,13 +830,13 @@ class RoutersClient(metaclass=RoutersClientMeta):
 
     def get_nat_mapping_info(
         self,
-        request: Union[compute.GetNatMappingInfoRoutersRequest, dict] = None,
+        request: Optional[Union[compute.GetNatMappingInfoRoutersRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        router: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        router: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.GetNatMappingInfoPager:
         r"""Retrieves runtime Nat mapping information of VM
@@ -929,13 +943,13 @@ class RoutersClient(metaclass=RoutersClientMeta):
 
     def get_router_status(
         self,
-        request: Union[compute.GetRouterStatusRouterRequest, dict] = None,
+        request: Optional[Union[compute.GetRouterStatusRouterRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        router: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        router: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.RouterStatusResponse:
         r"""Retrieves runtime information of the specified
@@ -1025,13 +1039,13 @@ class RoutersClient(metaclass=RoutersClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertRouterRequest, dict] = None,
+        request: Optional[Union[compute.InsertRouterRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        router_resource: compute.Router = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        router_resource: Optional[compute.Router] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a Router resource in the specified project
@@ -1121,13 +1135,13 @@ class RoutersClient(metaclass=RoutersClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertRouterRequest, dict] = None,
+        request: Optional[Union[compute.InsertRouterRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        router_resource: compute.Router = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        router_resource: Optional[compute.Router] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a Router resource in the specified project
@@ -1242,12 +1256,12 @@ class RoutersClient(metaclass=RoutersClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListRoutersRequest, dict] = None,
+        request: Optional[Union[compute.ListRoutersRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves a list of Router resources available to the
@@ -1341,14 +1355,14 @@ class RoutersClient(metaclass=RoutersClientMeta):
 
     def patch_unary(
         self,
-        request: Union[compute.PatchRouterRequest, dict] = None,
+        request: Optional[Union[compute.PatchRouterRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        router: str = None,
-        router_resource: compute.Router = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        router: Optional[str] = None,
+        router_resource: Optional[compute.Router] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Patches the specified Router resource with the data
@@ -1448,14 +1462,14 @@ class RoutersClient(metaclass=RoutersClientMeta):
 
     def patch(
         self,
-        request: Union[compute.PatchRouterRequest, dict] = None,
+        request: Optional[Union[compute.PatchRouterRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        router: str = None,
-        router_resource: compute.Router = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        router: Optional[str] = None,
+        router_resource: Optional[compute.Router] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Patches the specified Router resource with the data
@@ -1580,14 +1594,14 @@ class RoutersClient(metaclass=RoutersClientMeta):
 
     def preview(
         self,
-        request: Union[compute.PreviewRouterRequest, dict] = None,
+        request: Optional[Union[compute.PreviewRouterRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        router: str = None,
-        router_resource: compute.Router = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        router: Optional[str] = None,
+        router_resource: Optional[compute.Router] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.RoutersPreviewResponse:
         r"""Preview fields auto-generated during router create
@@ -1684,14 +1698,14 @@ class RoutersClient(metaclass=RoutersClientMeta):
 
     def update_unary(
         self,
-        request: Union[compute.UpdateRouterRequest, dict] = None,
+        request: Optional[Union[compute.UpdateRouterRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        router: str = None,
-        router_resource: compute.Router = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        router: Optional[str] = None,
+        router_resource: Optional[compute.Router] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Updates the specified Router resource with the data
@@ -1795,14 +1809,14 @@ class RoutersClient(metaclass=RoutersClientMeta):
 
     def update(
         self,
-        request: Union[compute.UpdateRouterRequest, dict] = None,
+        request: Optional[Union[compute.UpdateRouterRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        router: str = None,
-        router_resource: compute.Router = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        router: Optional[str] = None,
+        router_resource: Optional[compute.Router] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Updates the specified Router resource with the data
@@ -1943,14 +1957,9 @@ class RoutersClient(metaclass=RoutersClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("RoutersClient",)
