@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import RoutersTransport
-from .rest import RoutersRestTransport
-from .rest import RoutersRestInterceptor
-
+from .rest import RoutersRestInterceptor, RoutersRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[RoutersTransport]]
