@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.routes import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import RoutesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, RoutesTransport
 from .transports.rest import RoutesRestTransport
 
 
@@ -56,7 +69,7 @@ class RoutesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[RoutesTransport]:
         """Returns an appropriate transport class.
 
@@ -254,7 +267,7 @@ class RoutesClient(metaclass=RoutesClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -309,8 +322,8 @@ class RoutesClient(metaclass=RoutesClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, RoutesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, RoutesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the routes client.
@@ -327,7 +340,7 @@ class RoutesClient(metaclass=RoutesClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -357,6 +370,7 @@ class RoutesClient(metaclass=RoutesClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -409,12 +423,12 @@ class RoutesClient(metaclass=RoutesClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteRouteRequest, dict] = None,
+        request: Optional[Union[compute.DeleteRouteRequest, dict]] = None,
         *,
-        project: str = None,
-        route: str = None,
+        project: Optional[str] = None,
+        route: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified Route resource.
@@ -496,12 +510,12 @@ class RoutesClient(metaclass=RoutesClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteRouteRequest, dict] = None,
+        request: Optional[Union[compute.DeleteRouteRequest, dict]] = None,
         *,
-        project: str = None,
-        route: str = None,
+        project: Optional[str] = None,
+        route: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified Route resource.
@@ -607,12 +621,12 @@ class RoutesClient(metaclass=RoutesClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetRouteRequest, dict] = None,
+        request: Optional[Union[compute.GetRouteRequest, dict]] = None,
         *,
-        project: str = None,
-        route: str = None,
+        project: Optional[str] = None,
+        route: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Route:
         r"""Returns the specified Route resource. Gets a list of
@@ -699,12 +713,12 @@ class RoutesClient(metaclass=RoutesClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertRouteRequest, dict] = None,
+        request: Optional[Union[compute.InsertRouteRequest, dict]] = None,
         *,
-        project: str = None,
-        route_resource: compute.Route = None,
+        project: Optional[str] = None,
+        route_resource: Optional[compute.Route] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a Route resource in the specified project
@@ -782,12 +796,12 @@ class RoutesClient(metaclass=RoutesClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertRouteRequest, dict] = None,
+        request: Optional[Union[compute.InsertRouteRequest, dict]] = None,
         *,
-        project: str = None,
-        route_resource: compute.Route = None,
+        project: Optional[str] = None,
+        route_resource: Optional[compute.Route] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a Route resource in the specified project
@@ -889,11 +903,11 @@ class RoutesClient(metaclass=RoutesClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListRoutesRequest, dict] = None,
+        request: Optional[Union[compute.ListRoutesRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves the list of Route resources available to
@@ -987,14 +1001,9 @@ class RoutesClient(metaclass=RoutesClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("RoutesClient",)
