@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import SecurityPoliciesTransport
-from .rest import SecurityPoliciesRestTransport
-from .rest import SecurityPoliciesRestInterceptor
-
+from .rest import SecurityPoliciesRestInterceptor, SecurityPoliciesRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[SecurityPoliciesTransport]]
