@@ -14,25 +14,22 @@
 # limitations under the License.
 #
 
-from google.auth.transport.requests import AuthorizedSession  # type: ignore
-import json  # type: ignore
-import grpc  # type: ignore
-from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth import credentials as ga_credentials  # type: ignore
-from google.api_core import exceptions as core_exceptions
-from google.api_core import retry as retries
-from google.api_core import rest_helpers
-from google.api_core import rest_streaming
-from google.api_core import path_template
-from google.api_core import gapic_v1
-
-from google.protobuf import json_format
-from requests import __version__ as requests_version
 import dataclasses
+import json  # type: ignore
 import re
 from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
+from google.api_core import gapic_v1, path_template, rest_helpers, rest_streaming
+from google.api_core import exceptions as core_exceptions
+from google.api_core import retry as retries
+from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.transport.grpc import SslCredentials  # type: ignore
+from google.auth.transport.requests import AuthorizedSession  # type: ignore
+from google.protobuf import json_format
+import grpc  # type: ignore
+from requests import __version__ as requests_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
@@ -41,11 +38,8 @@ except AttributeError:  # pragma: NO COVER
 
 from google.cloud.compute_v1.types import compute
 
-from .base import (
-    SecurityPoliciesTransport,
-    DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO,
-)
-
+from .base import DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO
+from .base import SecurityPoliciesTransport
 
 DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     gapic_version=BASE_DEFAULT_CLIENT_INFO.gapic_version,
@@ -69,89 +63,101 @@ class SecurityPoliciesRestInterceptor:
 
     .. code-block:: python
         class MyCustomSecurityPoliciesInterceptor(SecurityPoliciesRestInterceptor):
-            def pre_add_rule(request, metadata):
+            def pre_add_rule(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_add_rule(response):
+            def post_add_rule(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_aggregated_list(request, metadata):
+            def pre_aggregated_list(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_aggregated_list(response):
+            def post_aggregated_list(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_delete(request, metadata):
+            def pre_delete(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_delete(response):
+            def post_delete(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_get(request, metadata):
+            def pre_get(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get(response):
+            def post_get(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_get_rule(request, metadata):
+            def pre_get_rule(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get_rule(response):
+            def post_get_rule(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_insert(request, metadata):
+            def pre_insert(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_insert(response):
+            def post_insert(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_list(request, metadata):
+            def pre_list(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_list(response):
+            def post_list(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_list_preconfigured_expression_sets(request, metadata):
+            def pre_list_preconfigured_expression_sets(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_list_preconfigured_expression_sets(response):
+            def post_list_preconfigured_expression_sets(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_patch(request, metadata):
+            def pre_patch(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_patch(response):
+            def post_patch(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_patch_rule(request, metadata):
+            def pre_patch_rule(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_patch_rule(response):
+            def post_patch_rule(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_remove_rule(request, metadata):
+            def pre_remove_rule(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_remove_rule(response):
+            def post_remove_rule(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_set_labels(request, metadata):
+            def pre_set_labels(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_set_labels(response):
+            def post_set_labels(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
         transport = SecurityPoliciesRestTransport(interceptor=MyCustomSecurityPoliciesInterceptor())
         client = SecurityPoliciesClient(transport=transport)
@@ -452,10 +458,10 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
-        scopes: Sequence[str] = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
@@ -547,7 +553,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
             request: compute.AddRuleSecurityPolicyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the add rule method over HTTP.
@@ -658,7 +664,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
             request: compute.AggregatedListSecurityPoliciesRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.SecurityPoliciesAggregatedList:
             r"""Call the aggregated list method over HTTP.
@@ -745,7 +751,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
             request: compute.DeleteSecurityPolicyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the delete method over HTTP.
@@ -847,7 +853,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
             request: compute.GetSecurityPolicyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.SecurityPolicy:
             r"""Call the get method over HTTP.
@@ -940,7 +946,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
             request: compute.GetRuleSecurityPolicyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.SecurityPolicyRule:
             r"""Call the get rule method over HTTP.
@@ -1031,7 +1037,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
             request: compute.InsertSecurityPolicyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the insert method over HTTP.
@@ -1142,7 +1148,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
             request: compute.ListSecurityPoliciesRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.SecurityPolicyList:
             r"""Call the list method over HTTP.
@@ -1229,7 +1235,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
             request: compute.ListPreconfiguredExpressionSetsSecurityPoliciesRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.SecurityPoliciesListPreconfiguredExpressionSetsResponse:
             r"""Call the list preconfigured
@@ -1328,7 +1334,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
             request: compute.PatchSecurityPolicyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the patch method over HTTP.
@@ -1439,7 +1445,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
             request: compute.PatchRuleSecurityPolicyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the patch rule method over HTTP.
@@ -1550,7 +1556,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
             request: compute.RemoveRuleSecurityPolicyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the remove rule method over HTTP.
@@ -1652,7 +1658,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
             request: compute.SetLabelsSecurityPolicyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the set labels method over HTTP.
