@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.service_attachments import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import ServiceAttachmentsTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, ServiceAttachmentsTransport
 from .transports.rest import ServiceAttachmentsRestTransport
 
 
@@ -58,7 +71,7 @@ class ServiceAttachmentsClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[ServiceAttachmentsTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, ServiceAttachmentsTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, ServiceAttachmentsTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the service attachments client.
@@ -329,7 +342,7 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,11 +425,13 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
 
     def aggregated_list(
         self,
-        request: Union[compute.AggregatedListServiceAttachmentsRequest, dict] = None,
+        request: Optional[
+            Union[compute.AggregatedListServiceAttachmentsRequest, dict]
+        ] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Retrieves the list of all ServiceAttachment
@@ -502,13 +518,13 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteServiceAttachmentRequest, dict] = None,
+        request: Optional[Union[compute.DeleteServiceAttachmentRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        service_attachment: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        service_attachment: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified ServiceAttachment in the given
@@ -602,13 +618,13 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteServiceAttachmentRequest, dict] = None,
+        request: Optional[Union[compute.DeleteServiceAttachmentRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        service_attachment: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        service_attachment: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified ServiceAttachment in the given
@@ -727,13 +743,13 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetServiceAttachmentRequest, dict] = None,
+        request: Optional[Union[compute.GetServiceAttachmentRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        service_attachment: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        service_attachment: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.ServiceAttachment:
         r"""Returns the specified ServiceAttachment resource in
@@ -834,13 +850,15 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
 
     def get_iam_policy(
         self,
-        request: Union[compute.GetIamPolicyServiceAttachmentRequest, dict] = None,
+        request: Optional[
+            Union[compute.GetIamPolicyServiceAttachmentRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        resource: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        resource: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Policy:
         r"""Gets the access control policy for a resource. May be
@@ -974,13 +992,13 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertServiceAttachmentRequest, dict] = None,
+        request: Optional[Union[compute.InsertServiceAttachmentRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        service_attachment_resource: compute.ServiceAttachment = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        service_attachment_resource: Optional[compute.ServiceAttachment] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a ServiceAttachment in the specified project
@@ -1072,13 +1090,13 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertServiceAttachmentRequest, dict] = None,
+        request: Optional[Union[compute.InsertServiceAttachmentRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        service_attachment_resource: compute.ServiceAttachment = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        service_attachment_resource: Optional[compute.ServiceAttachment] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a ServiceAttachment in the specified project
@@ -1195,12 +1213,12 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListServiceAttachmentsRequest, dict] = None,
+        request: Optional[Union[compute.ListServiceAttachmentsRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Lists the ServiceAttachments for a project in the
@@ -1294,14 +1312,14 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
 
     def patch_unary(
         self,
-        request: Union[compute.PatchServiceAttachmentRequest, dict] = None,
+        request: Optional[Union[compute.PatchServiceAttachmentRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        service_attachment: str = None,
-        service_attachment_resource: compute.ServiceAttachment = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        service_attachment: Optional[str] = None,
+        service_attachment_resource: Optional[compute.ServiceAttachment] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Patches the specified ServiceAttachment resource with
@@ -1410,14 +1428,14 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
 
     def patch(
         self,
-        request: Union[compute.PatchServiceAttachmentRequest, dict] = None,
+        request: Optional[Union[compute.PatchServiceAttachmentRequest, dict]] = None,
         *,
-        project: str = None,
-        region: str = None,
-        service_attachment: str = None,
-        service_attachment_resource: compute.ServiceAttachment = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        service_attachment: Optional[str] = None,
+        service_attachment_resource: Optional[compute.ServiceAttachment] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Patches the specified ServiceAttachment resource with
@@ -1551,14 +1569,18 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
 
     def set_iam_policy(
         self,
-        request: Union[compute.SetIamPolicyServiceAttachmentRequest, dict] = None,
+        request: Optional[
+            Union[compute.SetIamPolicyServiceAttachmentRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        resource: str = None,
-        region_set_policy_request_resource: compute.RegionSetPolicyRequest = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        resource: Optional[str] = None,
+        region_set_policy_request_resource: Optional[
+            compute.RegionSetPolicyRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Policy:
         r"""Sets the access control policy on the specified
@@ -1703,14 +1725,18 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
 
     def test_iam_permissions(
         self,
-        request: Union[compute.TestIamPermissionsServiceAttachmentRequest, dict] = None,
+        request: Optional[
+            Union[compute.TestIamPermissionsServiceAttachmentRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        region: str = None,
-        resource: str = None,
-        test_permissions_request_resource: compute.TestPermissionsRequest = None,
+        project: Optional[str] = None,
+        region: Optional[str] = None,
+        resource: Optional[str] = None,
+        test_permissions_request_resource: Optional[
+            compute.TestPermissionsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.TestPermissionsResponse:
         r"""Returns permissions that a caller has on the
@@ -1827,14 +1853,9 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("ServiceAttachmentsClient",)
