@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import ServiceAttachmentsTransport
-from .rest import ServiceAttachmentsRestTransport
-from .rest import ServiceAttachmentsRestInterceptor
-
+from .rest import ServiceAttachmentsRestInterceptor, ServiceAttachmentsRestTransport
 
 # Compile a registry of transports.
 _transport_registry = (
