@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.snapshots import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import SnapshotsTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, SnapshotsTransport
 from .transports.rest import SnapshotsRestTransport
 
 
@@ -56,7 +69,7 @@ class SnapshotsClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[SnapshotsTransport]:
         """Returns an appropriate transport class.
 
@@ -254,7 +267,7 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -309,8 +322,8 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, SnapshotsTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, SnapshotsTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the snapshots client.
@@ -327,7 +340,7 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -357,6 +370,7 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -409,12 +423,12 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteSnapshotRequest, dict] = None,
+        request: Optional[Union[compute.DeleteSnapshotRequest, dict]] = None,
         *,
-        project: str = None,
-        snapshot: str = None,
+        project: Optional[str] = None,
+        snapshot: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified Snapshot resource. Keep in mind
@@ -505,12 +519,12 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteSnapshotRequest, dict] = None,
+        request: Optional[Union[compute.DeleteSnapshotRequest, dict]] = None,
         *,
-        project: str = None,
-        snapshot: str = None,
+        project: Optional[str] = None,
+        snapshot: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified Snapshot resource. Keep in mind
@@ -625,12 +639,12 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetSnapshotRequest, dict] = None,
+        request: Optional[Union[compute.GetSnapshotRequest, dict]] = None,
         *,
-        project: str = None,
-        snapshot: str = None,
+        project: Optional[str] = None,
+        snapshot: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Snapshot:
         r"""Returns the specified Snapshot resource. Gets a list
@@ -718,12 +732,12 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
 
     def get_iam_policy(
         self,
-        request: Union[compute.GetIamPolicySnapshotRequest, dict] = None,
+        request: Optional[Union[compute.GetIamPolicySnapshotRequest, dict]] = None,
         *,
-        project: str = None,
-        resource: str = None,
+        project: Optional[str] = None,
+        resource: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Policy:
         r"""Gets the access control policy for a resource. May be
@@ -847,12 +861,12 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertSnapshotRequest, dict] = None,
+        request: Optional[Union[compute.InsertSnapshotRequest, dict]] = None,
         *,
-        project: str = None,
-        snapshot_resource: compute.Snapshot = None,
+        project: Optional[str] = None,
+        snapshot_resource: Optional[compute.Snapshot] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a snapshot in the specified project using the
@@ -935,12 +949,12 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertSnapshotRequest, dict] = None,
+        request: Optional[Union[compute.InsertSnapshotRequest, dict]] = None,
         *,
-        project: str = None,
-        snapshot_resource: compute.Snapshot = None,
+        project: Optional[str] = None,
+        snapshot_resource: Optional[compute.Snapshot] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a snapshot in the specified project using the
@@ -1047,11 +1061,11 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListSnapshotsRequest, dict] = None,
+        request: Optional[Union[compute.ListSnapshotsRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves the list of Snapshot resources contained
@@ -1134,13 +1148,15 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
 
     def set_iam_policy(
         self,
-        request: Union[compute.SetIamPolicySnapshotRequest, dict] = None,
+        request: Optional[Union[compute.SetIamPolicySnapshotRequest, dict]] = None,
         *,
-        project: str = None,
-        resource: str = None,
-        global_set_policy_request_resource: compute.GlobalSetPolicyRequest = None,
+        project: Optional[str] = None,
+        resource: Optional[str] = None,
+        global_set_policy_request_resource: Optional[
+            compute.GlobalSetPolicyRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Policy:
         r"""Sets the access control policy on the specified
@@ -1275,13 +1291,15 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
 
     def set_labels_unary(
         self,
-        request: Union[compute.SetLabelsSnapshotRequest, dict] = None,
+        request: Optional[Union[compute.SetLabelsSnapshotRequest, dict]] = None,
         *,
-        project: str = None,
-        resource: str = None,
-        global_set_labels_request_resource: compute.GlobalSetLabelsRequest = None,
+        project: Optional[str] = None,
+        resource: Optional[str] = None,
+        global_set_labels_request_resource: Optional[
+            compute.GlobalSetLabelsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Sets the labels on a snapshot. To learn more about
@@ -1378,13 +1396,15 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
 
     def set_labels(
         self,
-        request: Union[compute.SetLabelsSnapshotRequest, dict] = None,
+        request: Optional[Union[compute.SetLabelsSnapshotRequest, dict]] = None,
         *,
-        project: str = None,
-        resource: str = None,
-        global_set_labels_request_resource: compute.GlobalSetLabelsRequest = None,
+        project: Optional[str] = None,
+        resource: Optional[str] = None,
+        global_set_labels_request_resource: Optional[
+            compute.GlobalSetLabelsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Sets the labels on a snapshot. To learn more about
@@ -1505,13 +1525,17 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
 
     def test_iam_permissions(
         self,
-        request: Union[compute.TestIamPermissionsSnapshotRequest, dict] = None,
+        request: Optional[
+            Union[compute.TestIamPermissionsSnapshotRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        resource: str = None,
-        test_permissions_request_resource: compute.TestPermissionsRequest = None,
+        project: Optional[str] = None,
+        resource: Optional[str] = None,
+        test_permissions_request_resource: Optional[
+            compute.TestPermissionsRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.TestPermissionsResponse:
         r"""Returns permissions that a caller has on the
@@ -1618,14 +1642,9 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("SnapshotsClient",)
