@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import SslCertificatesTransport
-from .rest import SslCertificatesRestTransport
-from .rest import SslCertificatesRestInterceptor
-
+from .rest import SslCertificatesRestInterceptor, SslCertificatesRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[SslCertificatesTransport]]
