@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.ssl_policies import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import SslPoliciesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, SslPoliciesTransport
 from .transports.rest import SslPoliciesRestTransport
 
 
@@ -56,7 +69,7 @@ class SslPoliciesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[SslPoliciesTransport]:
         """Returns an appropriate transport class.
 
@@ -254,7 +267,7 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -309,8 +322,8 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, SslPoliciesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, SslPoliciesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the ssl policies client.
@@ -327,7 +340,7 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -357,6 +370,7 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -409,11 +423,11 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
 
     def aggregated_list(
         self,
-        request: Union[compute.AggregatedListSslPoliciesRequest, dict] = None,
+        request: Optional[Union[compute.AggregatedListSslPoliciesRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Retrieves the list of all SslPolicy resources,
@@ -497,12 +511,12 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteSslPolicyRequest, dict] = None,
+        request: Optional[Union[compute.DeleteSslPolicyRequest, dict]] = None,
         *,
-        project: str = None,
-        ssl_policy: str = None,
+        project: Optional[str] = None,
+        ssl_policy: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified SSL policy. The SSL policy
@@ -590,12 +604,12 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteSslPolicyRequest, dict] = None,
+        request: Optional[Union[compute.DeleteSslPolicyRequest, dict]] = None,
         *,
-        project: str = None,
-        ssl_policy: str = None,
+        project: Optional[str] = None,
+        ssl_policy: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified SSL policy. The SSL policy
@@ -707,12 +721,12 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetSslPolicyRequest, dict] = None,
+        request: Optional[Union[compute.GetSslPolicyRequest, dict]] = None,
         *,
-        project: str = None,
-        ssl_policy: str = None,
+        project: Optional[str] = None,
+        ssl_policy: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.SslPolicy:
         r"""Lists all of the ordered rules present in a single
@@ -802,12 +816,12 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertSslPolicyRequest, dict] = None,
+        request: Optional[Union[compute.InsertSslPolicyRequest, dict]] = None,
         *,
-        project: str = None,
-        ssl_policy_resource: compute.SslPolicy = None,
+        project: Optional[str] = None,
+        ssl_policy_resource: Optional[compute.SslPolicy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Returns the specified SSL policy resource. Gets a
@@ -887,12 +901,12 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertSslPolicyRequest, dict] = None,
+        request: Optional[Union[compute.InsertSslPolicyRequest, dict]] = None,
         *,
-        project: str = None,
-        ssl_policy_resource: compute.SslPolicy = None,
+        project: Optional[str] = None,
+        ssl_policy_resource: Optional[compute.SslPolicy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Returns the specified SSL policy resource. Gets a
@@ -996,11 +1010,11 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListSslPoliciesRequest, dict] = None,
+        request: Optional[Union[compute.ListSslPoliciesRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Lists all the SSL policies that have been configured
@@ -1082,11 +1096,13 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
 
     def list_available_features(
         self,
-        request: Union[compute.ListAvailableFeaturesSslPoliciesRequest, dict] = None,
+        request: Optional[
+            Union[compute.ListAvailableFeaturesSslPoliciesRequest, dict]
+        ] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.SslPoliciesListAvailableFeaturesResponse:
         r"""Lists all features that can be specified in the SSL
@@ -1156,13 +1172,13 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
 
     def patch_unary(
         self,
-        request: Union[compute.PatchSslPolicyRequest, dict] = None,
+        request: Optional[Union[compute.PatchSslPolicyRequest, dict]] = None,
         *,
-        project: str = None,
-        ssl_policy: str = None,
-        ssl_policy_resource: compute.SslPolicy = None,
+        project: Optional[str] = None,
+        ssl_policy: Optional[str] = None,
+        ssl_policy_resource: Optional[compute.SslPolicy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Patches the specified SSL policy with the data
@@ -1256,13 +1272,13 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
 
     def patch(
         self,
-        request: Union[compute.PatchSslPolicyRequest, dict] = None,
+        request: Optional[Union[compute.PatchSslPolicyRequest, dict]] = None,
         *,
-        project: str = None,
-        ssl_policy: str = None,
-        ssl_policy_resource: compute.SslPolicy = None,
+        project: Optional[str] = None,
+        ssl_policy: Optional[str] = None,
+        ssl_policy_resource: Optional[compute.SslPolicy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Patches the specified SSL policy with the data
@@ -1392,14 +1408,9 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("SslPoliciesClient",)
