@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.target_grpc_proxies import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import TargetGrpcProxiesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, TargetGrpcProxiesTransport
 from .transports.rest import TargetGrpcProxiesRestTransport
 
 
@@ -58,7 +71,7 @@ class TargetGrpcProxiesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[TargetGrpcProxiesTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, TargetGrpcProxiesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, TargetGrpcProxiesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the target grpc proxies client.
@@ -329,7 +342,7 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,12 +425,12 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteTargetGrpcProxyRequest, dict] = None,
+        request: Optional[Union[compute.DeleteTargetGrpcProxyRequest, dict]] = None,
         *,
-        project: str = None,
-        target_grpc_proxy: str = None,
+        project: Optional[str] = None,
+        target_grpc_proxy: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified TargetGrpcProxy in the given
@@ -502,12 +516,12 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteTargetGrpcProxyRequest, dict] = None,
+        request: Optional[Union[compute.DeleteTargetGrpcProxyRequest, dict]] = None,
         *,
-        project: str = None,
-        target_grpc_proxy: str = None,
+        project: Optional[str] = None,
+        target_grpc_proxy: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified TargetGrpcProxy in the given
@@ -617,12 +631,12 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetTargetGrpcProxyRequest, dict] = None,
+        request: Optional[Union[compute.GetTargetGrpcProxyRequest, dict]] = None,
         *,
-        project: str = None,
-        target_grpc_proxy: str = None,
+        project: Optional[str] = None,
+        target_grpc_proxy: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.TargetGrpcProxy:
         r"""Returns the specified TargetGrpcProxy resource in the
@@ -713,12 +727,12 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertTargetGrpcProxyRequest, dict] = None,
+        request: Optional[Union[compute.InsertTargetGrpcProxyRequest, dict]] = None,
         *,
-        project: str = None,
-        target_grpc_proxy_resource: compute.TargetGrpcProxy = None,
+        project: Optional[str] = None,
+        target_grpc_proxy_resource: Optional[compute.TargetGrpcProxy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a TargetGrpcProxy in the specified project in
@@ -798,12 +812,12 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertTargetGrpcProxyRequest, dict] = None,
+        request: Optional[Union[compute.InsertTargetGrpcProxyRequest, dict]] = None,
         *,
-        project: str = None,
-        target_grpc_proxy_resource: compute.TargetGrpcProxy = None,
+        project: Optional[str] = None,
+        target_grpc_proxy_resource: Optional[compute.TargetGrpcProxy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a TargetGrpcProxy in the specified project in
@@ -907,11 +921,11 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListTargetGrpcProxiesRequest, dict] = None,
+        request: Optional[Union[compute.ListTargetGrpcProxiesRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Lists the TargetGrpcProxies for a project in the
@@ -993,13 +1007,13 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
 
     def patch_unary(
         self,
-        request: Union[compute.PatchTargetGrpcProxyRequest, dict] = None,
+        request: Optional[Union[compute.PatchTargetGrpcProxyRequest, dict]] = None,
         *,
-        project: str = None,
-        target_grpc_proxy: str = None,
-        target_grpc_proxy_resource: compute.TargetGrpcProxy = None,
+        project: Optional[str] = None,
+        target_grpc_proxy: Optional[str] = None,
+        target_grpc_proxy_resource: Optional[compute.TargetGrpcProxy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Patches the specified TargetGrpcProxy resource with
@@ -1096,13 +1110,13 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
 
     def patch(
         self,
-        request: Union[compute.PatchTargetGrpcProxyRequest, dict] = None,
+        request: Optional[Union[compute.PatchTargetGrpcProxyRequest, dict]] = None,
         *,
-        project: str = None,
-        target_grpc_proxy: str = None,
-        target_grpc_proxy_resource: compute.TargetGrpcProxy = None,
+        project: Optional[str] = None,
+        target_grpc_proxy: Optional[str] = None,
+        target_grpc_proxy_resource: Optional[compute.TargetGrpcProxy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Patches the specified TargetGrpcProxy resource with
@@ -1235,14 +1249,9 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("TargetGrpcProxiesClient",)
