@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import TargetHttpProxiesTransport
-from .rest import TargetHttpProxiesRestTransport
-from .rest import TargetHttpProxiesRestInterceptor
-
+from .rest import TargetHttpProxiesRestInterceptor, TargetHttpProxiesRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[TargetHttpProxiesTransport]]
