@@ -14,25 +14,22 @@
 # limitations under the License.
 #
 
-from google.auth.transport.requests import AuthorizedSession  # type: ignore
-import json  # type: ignore
-import grpc  # type: ignore
-from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth import credentials as ga_credentials  # type: ignore
-from google.api_core import exceptions as core_exceptions
-from google.api_core import retry as retries
-from google.api_core import rest_helpers
-from google.api_core import rest_streaming
-from google.api_core import path_template
-from google.api_core import gapic_v1
-
-from google.protobuf import json_format
-from requests import __version__ as requests_version
 import dataclasses
+import json  # type: ignore
 import re
 from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
+from google.api_core import gapic_v1, path_template, rest_helpers, rest_streaming
+from google.api_core import exceptions as core_exceptions
+from google.api_core import retry as retries
+from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.transport.grpc import SslCredentials  # type: ignore
+from google.auth.transport.requests import AuthorizedSession  # type: ignore
+from google.protobuf import json_format
+import grpc  # type: ignore
+from requests import __version__ as requests_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
@@ -41,11 +38,8 @@ except AttributeError:  # pragma: NO COVER
 
 from google.cloud.compute_v1.types import compute
 
-from .base import (
-    TargetHttpsProxiesTransport,
-    DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO,
-)
-
+from .base import DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO
+from .base import TargetHttpsProxiesTransport
 
 DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     gapic_version=BASE_DEFAULT_CLIENT_INFO.gapic_version,
@@ -69,82 +63,93 @@ class TargetHttpsProxiesRestInterceptor:
 
     .. code-block:: python
         class MyCustomTargetHttpsProxiesInterceptor(TargetHttpsProxiesRestInterceptor):
-            def pre_aggregated_list(request, metadata):
+            def pre_aggregated_list(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_aggregated_list(response):
+            def post_aggregated_list(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_delete(request, metadata):
+            def pre_delete(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_delete(response):
+            def post_delete(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_get(request, metadata):
+            def pre_get(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get(response):
+            def post_get(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_insert(request, metadata):
+            def pre_insert(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_insert(response):
+            def post_insert(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_list(request, metadata):
+            def pre_list(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_list(response):
+            def post_list(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_patch(request, metadata):
+            def pre_patch(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_patch(response):
+            def post_patch(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_set_certificate_map(request, metadata):
+            def pre_set_certificate_map(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_set_certificate_map(response):
+            def post_set_certificate_map(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_set_quic_override(request, metadata):
+            def pre_set_quic_override(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_set_quic_override(response):
+            def post_set_quic_override(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_set_ssl_certificates(request, metadata):
+            def pre_set_ssl_certificates(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_set_ssl_certificates(response):
+            def post_set_ssl_certificates(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_set_ssl_policy(request, metadata):
+            def pre_set_ssl_policy(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_set_ssl_policy(response):
+            def post_set_ssl_policy(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_set_url_map(request, metadata):
+            def pre_set_url_map(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_set_url_map(response):
+            def post_set_url_map(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
         transport = TargetHttpsProxiesRestTransport(interceptor=MyCustomTargetHttpsProxiesInterceptor())
         client = TargetHttpsProxiesClient(transport=transport)
@@ -427,10 +432,10 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
-        scopes: Sequence[str] = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
@@ -522,7 +527,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
             request: compute.AggregatedListTargetHttpsProxiesRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.TargetHttpsProxyAggregatedList:
             r"""Call the aggregated list method over HTTP.
@@ -609,7 +614,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
             request: compute.DeleteTargetHttpsProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the delete method over HTTP.
@@ -711,7 +716,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
             request: compute.GetTargetHttpsProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.TargetHttpsProxy:
             r"""Call the get method over HTTP.
@@ -810,7 +815,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
             request: compute.InsertTargetHttpsProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the insert method over HTTP.
@@ -921,7 +926,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
             request: compute.ListTargetHttpsProxiesRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.TargetHttpsProxyList:
             r"""Call the list method over HTTP.
@@ -1010,7 +1015,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
             request: compute.PatchTargetHttpsProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the patch method over HTTP.
@@ -1121,7 +1126,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
             request: compute.SetCertificateMapTargetHttpsProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the set certificate map method over HTTP.
@@ -1234,7 +1239,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
             request: compute.SetQuicOverrideTargetHttpsProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the set quic override method over HTTP.
@@ -1347,7 +1352,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
             request: compute.SetSslCertificatesTargetHttpsProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the set ssl certificates method over HTTP.
@@ -1460,7 +1465,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
             request: compute.SetSslPolicyTargetHttpsProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the set ssl policy method over HTTP.
@@ -1571,7 +1576,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
             request: compute.SetUrlMapTargetHttpsProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the set url map method over HTTP.
