@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.target_instances import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import TargetInstancesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, TargetInstancesTransport
 from .transports.rest import TargetInstancesRestTransport
 
 
@@ -58,7 +71,7 @@ class TargetInstancesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[TargetInstancesTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, TargetInstancesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, TargetInstancesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the target instances client.
@@ -329,7 +342,7 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,11 +425,13 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
 
     def aggregated_list(
         self,
-        request: Union[compute.AggregatedListTargetInstancesRequest, dict] = None,
+        request: Optional[
+            Union[compute.AggregatedListTargetInstancesRequest, dict]
+        ] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Retrieves an aggregated list of target instances.
@@ -496,13 +512,13 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteTargetInstanceRequest, dict] = None,
+        request: Optional[Union[compute.DeleteTargetInstanceRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        target_instance: str = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        target_instance: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified TargetInstance resource.
@@ -597,13 +613,13 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteTargetInstanceRequest, dict] = None,
+        request: Optional[Union[compute.DeleteTargetInstanceRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        target_instance: str = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        target_instance: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified TargetInstance resource.
@@ -723,13 +739,13 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetTargetInstanceRequest, dict] = None,
+        request: Optional[Union[compute.GetTargetInstanceRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        target_instance: str = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        target_instance: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.TargetInstance:
         r"""Returns the specified TargetInstance resource. Gets a
@@ -832,13 +848,13 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertTargetInstanceRequest, dict] = None,
+        request: Optional[Union[compute.InsertTargetInstanceRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        target_instance_resource: compute.TargetInstance = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        target_instance_resource: Optional[compute.TargetInstance] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a TargetInstance resource in the specified
@@ -931,13 +947,13 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertTargetInstanceRequest, dict] = None,
+        request: Optional[Union[compute.InsertTargetInstanceRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
-        target_instance_resource: compute.TargetInstance = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
+        target_instance_resource: Optional[compute.TargetInstance] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a TargetInstance resource in the specified
@@ -1055,12 +1071,12 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListTargetInstancesRequest, dict] = None,
+        request: Optional[Union[compute.ListTargetInstancesRequest, dict]] = None,
         *,
-        project: str = None,
-        zone: str = None,
+        project: Optional[str] = None,
+        zone: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves a list of TargetInstance resources
@@ -1170,14 +1186,9 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("TargetInstancesClient",)
