@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import TargetInstancesTransport
-from .rest import TargetInstancesRestTransport
-from .rest import TargetInstancesRestInterceptor
-
+from .rest import TargetInstancesRestInterceptor, TargetInstancesRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[TargetInstancesTransport]]
