@@ -14,25 +14,22 @@
 # limitations under the License.
 #
 
-from google.auth.transport.requests import AuthorizedSession  # type: ignore
-import json  # type: ignore
-import grpc  # type: ignore
-from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth import credentials as ga_credentials  # type: ignore
-from google.api_core import exceptions as core_exceptions
-from google.api_core import retry as retries
-from google.api_core import rest_helpers
-from google.api_core import rest_streaming
-from google.api_core import path_template
-from google.api_core import gapic_v1
-
-from google.protobuf import json_format
-from requests import __version__ as requests_version
 import dataclasses
+import json  # type: ignore
 import re
 from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
+from google.api_core import gapic_v1, path_template, rest_helpers, rest_streaming
+from google.api_core import exceptions as core_exceptions
+from google.api_core import retry as retries
+from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.transport.grpc import SslCredentials  # type: ignore
+from google.auth.transport.requests import AuthorizedSession  # type: ignore
+from google.protobuf import json_format
+import grpc  # type: ignore
+from requests import __version__ as requests_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
@@ -41,11 +38,8 @@ except AttributeError:  # pragma: NO COVER
 
 from google.cloud.compute_v1.types import compute
 
-from .base import (
-    TargetSslProxiesTransport,
-    DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO,
-)
-
+from .base import DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO
+from .base import TargetSslProxiesTransport
 
 DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     gapic_version=BASE_DEFAULT_CLIENT_INFO.gapic_version,
@@ -69,68 +63,77 @@ class TargetSslProxiesRestInterceptor:
 
     .. code-block:: python
         class MyCustomTargetSslProxiesInterceptor(TargetSslProxiesRestInterceptor):
-            def pre_delete(request, metadata):
+            def pre_delete(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_delete(response):
+            def post_delete(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_get(request, metadata):
+            def pre_get(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get(response):
+            def post_get(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_insert(request, metadata):
+            def pre_insert(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_insert(response):
+            def post_insert(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_list(request, metadata):
+            def pre_list(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_list(response):
+            def post_list(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_set_backend_service(request, metadata):
+            def pre_set_backend_service(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_set_backend_service(response):
+            def post_set_backend_service(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_set_certificate_map(request, metadata):
+            def pre_set_certificate_map(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_set_certificate_map(response):
+            def post_set_certificate_map(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_set_proxy_header(request, metadata):
+            def pre_set_proxy_header(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_set_proxy_header(response):
+            def post_set_proxy_header(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_set_ssl_certificates(request, metadata):
+            def pre_set_ssl_certificates(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_set_ssl_certificates(response):
+            def post_set_ssl_certificates(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_set_ssl_policy(request, metadata):
+            def pre_set_ssl_policy(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_set_ssl_policy(response):
+            def post_set_ssl_policy(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
         transport = TargetSslProxiesRestTransport(interceptor=MyCustomTargetSslProxiesInterceptor())
         client = TargetSslProxiesClient(transport=transport)
@@ -369,10 +372,10 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
-        scopes: Sequence[str] = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
@@ -464,7 +467,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
             request: compute.DeleteTargetSslProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the delete method over HTTP.
@@ -566,7 +569,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
             request: compute.GetTargetSslProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.TargetSslProxy:
             r"""Call the get method over HTTP.
@@ -661,7 +664,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
             request: compute.InsertTargetSslProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the insert method over HTTP.
@@ -772,7 +775,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
             request: compute.ListTargetSslProxiesRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.TargetSslProxyList:
             r"""Call the list method over HTTP.
@@ -861,7 +864,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
             request: compute.SetBackendServiceTargetSslProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the set backend service method over HTTP.
@@ -974,7 +977,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
             request: compute.SetCertificateMapTargetSslProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the set certificate map method over HTTP.
@@ -1087,7 +1090,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
             request: compute.SetProxyHeaderTargetSslProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the set proxy header method over HTTP.
@@ -1200,7 +1203,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
             request: compute.SetSslCertificatesTargetSslProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the set ssl certificates method over HTTP.
@@ -1313,7 +1316,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
             request: compute.SetSslPolicyTargetSslProxyRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> compute.Operation:
             r"""Call the set ssl policy method over HTTP.
