@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.target_tcp_proxies import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import TargetTcpProxiesTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, TargetTcpProxiesTransport
 from .transports.rest import TargetTcpProxiesRestTransport
 
 
@@ -58,7 +71,7 @@ class TargetTcpProxiesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[TargetTcpProxiesTransport]:
         """Returns an appropriate transport class.
 
@@ -256,7 +269,7 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -311,8 +324,8 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, TargetTcpProxiesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, TargetTcpProxiesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the target tcp proxies client.
@@ -329,7 +342,7 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +372,7 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -409,14 +423,104 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
                 api_audience=client_options.api_audience,
             )
 
+    def aggregated_list(
+        self,
+        request: Optional[
+            Union[compute.AggregatedListTargetTcpProxiesRequest, dict]
+        ] = None,
+        *,
+        project: Optional[str] = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> pagers.AggregatedListPager:
+        r"""Retrieves the list of all TargetTcpProxy resources,
+        regional and global, available to the specified project.
+
+        Args:
+            request (Union[google.cloud.compute_v1.types.AggregatedListTargetTcpProxiesRequest, dict]):
+                The request object. A request message for
+                TargetTcpProxies.AggregatedList. See the method
+                description for details.
+            project (str):
+                Name of the project scoping this
+                request.
+
+                This corresponds to the ``project`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.compute_v1.services.target_tcp_proxies.pagers.AggregatedListPager:
+                Iterating over this object will yield
+                results and resolve additional pages
+                automatically.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([project])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a compute.AggregatedListTargetTcpProxiesRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, compute.AggregatedListTargetTcpProxiesRequest):
+            request = compute.AggregatedListTargetTcpProxiesRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if project is not None:
+                request.project = project
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.aggregated_list]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # This method is paged; wrap the response in a pager, which provides
+        # an `__iter__` convenience method.
+        response = pagers.AggregatedListPager(
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     def delete_unary(
         self,
-        request: Union[compute.DeleteTargetTcpProxyRequest, dict] = None,
+        request: Optional[Union[compute.DeleteTargetTcpProxyRequest, dict]] = None,
         *,
-        project: str = None,
-        target_tcp_proxy: str = None,
+        project: Optional[str] = None,
+        target_tcp_proxy: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified TargetTcpProxy resource.
@@ -501,12 +605,12 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteTargetTcpProxyRequest, dict] = None,
+        request: Optional[Union[compute.DeleteTargetTcpProxyRequest, dict]] = None,
         *,
-        project: str = None,
-        target_tcp_proxy: str = None,
+        project: Optional[str] = None,
+        target_tcp_proxy: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified TargetTcpProxy resource.
@@ -615,12 +719,12 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetTargetTcpProxyRequest, dict] = None,
+        request: Optional[Union[compute.GetTargetTcpProxyRequest, dict]] = None,
         *,
-        project: str = None,
-        target_tcp_proxy: str = None,
+        project: Optional[str] = None,
+        target_tcp_proxy: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.TargetTcpProxy:
         r"""Returns the specified TargetTcpProxy resource. Gets a
@@ -713,12 +817,12 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertTargetTcpProxyRequest, dict] = None,
+        request: Optional[Union[compute.InsertTargetTcpProxyRequest, dict]] = None,
         *,
-        project: str = None,
-        target_tcp_proxy_resource: compute.TargetTcpProxy = None,
+        project: Optional[str] = None,
+        target_tcp_proxy_resource: Optional[compute.TargetTcpProxy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a TargetTcpProxy resource in the specified
@@ -797,12 +901,12 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertTargetTcpProxyRequest, dict] = None,
+        request: Optional[Union[compute.InsertTargetTcpProxyRequest, dict]] = None,
         *,
-        project: str = None,
-        target_tcp_proxy_resource: compute.TargetTcpProxy = None,
+        project: Optional[str] = None,
+        target_tcp_proxy_resource: Optional[compute.TargetTcpProxy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a TargetTcpProxy resource in the specified
@@ -905,11 +1009,11 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListTargetTcpProxiesRequest, dict] = None,
+        request: Optional[Union[compute.ListTargetTcpProxiesRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves the list of TargetTcpProxy resources
@@ -993,13 +1097,17 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
 
     def set_backend_service_unary(
         self,
-        request: Union[compute.SetBackendServiceTargetTcpProxyRequest, dict] = None,
+        request: Optional[
+            Union[compute.SetBackendServiceTargetTcpProxyRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        target_tcp_proxy: str = None,
-        target_tcp_proxies_set_backend_service_request_resource: compute.TargetTcpProxiesSetBackendServiceRequest = None,
+        project: Optional[str] = None,
+        target_tcp_proxy: Optional[str] = None,
+        target_tcp_proxies_set_backend_service_request_resource: Optional[
+            compute.TargetTcpProxiesSetBackendServiceRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Changes the BackendService for TargetTcpProxy.
@@ -1100,13 +1208,17 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
 
     def set_backend_service(
         self,
-        request: Union[compute.SetBackendServiceTargetTcpProxyRequest, dict] = None,
+        request: Optional[
+            Union[compute.SetBackendServiceTargetTcpProxyRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        target_tcp_proxy: str = None,
-        target_tcp_proxies_set_backend_service_request_resource: compute.TargetTcpProxiesSetBackendServiceRequest = None,
+        project: Optional[str] = None,
+        target_tcp_proxy: Optional[str] = None,
+        target_tcp_proxies_set_backend_service_request_resource: Optional[
+            compute.TargetTcpProxiesSetBackendServiceRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Changes the BackendService for TargetTcpProxy.
@@ -1231,13 +1343,17 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
 
     def set_proxy_header_unary(
         self,
-        request: Union[compute.SetProxyHeaderTargetTcpProxyRequest, dict] = None,
+        request: Optional[
+            Union[compute.SetProxyHeaderTargetTcpProxyRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        target_tcp_proxy: str = None,
-        target_tcp_proxies_set_proxy_header_request_resource: compute.TargetTcpProxiesSetProxyHeaderRequest = None,
+        project: Optional[str] = None,
+        target_tcp_proxy: Optional[str] = None,
+        target_tcp_proxies_set_proxy_header_request_resource: Optional[
+            compute.TargetTcpProxiesSetProxyHeaderRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Changes the ProxyHeaderType for TargetTcpProxy.
@@ -1337,13 +1453,17 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
 
     def set_proxy_header(
         self,
-        request: Union[compute.SetProxyHeaderTargetTcpProxyRequest, dict] = None,
+        request: Optional[
+            Union[compute.SetProxyHeaderTargetTcpProxyRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        target_tcp_proxy: str = None,
-        target_tcp_proxies_set_proxy_header_request_resource: compute.TargetTcpProxiesSetProxyHeaderRequest = None,
+        project: Optional[str] = None,
+        target_tcp_proxy: Optional[str] = None,
+        target_tcp_proxies_set_proxy_header_request_resource: Optional[
+            compute.TargetTcpProxiesSetProxyHeaderRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Changes the ProxyHeaderType for TargetTcpProxy.
@@ -1479,14 +1599,9 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("TargetTcpProxiesClient",)
