@@ -17,29 +17,42 @@ from collections import OrderedDict
 import functools
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
-from google.api_core import extended_operation
-from google.api_core import gapic_v1
+from google.api_core import extended_operation, gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import extended_operation  # type: ignore
+
 from google.cloud.compute_v1.services.url_maps import pagers
 from google.cloud.compute_v1.types import compute
-from .transports.base import UrlMapsTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, UrlMapsTransport
 from .transports.rest import UrlMapsRestTransport
 
 
@@ -56,7 +69,7 @@ class UrlMapsClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[UrlMapsTransport]:
         """Returns an appropriate transport class.
 
@@ -254,7 +267,7 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -309,8 +322,8 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, UrlMapsTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, UrlMapsTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the url maps client.
@@ -327,7 +340,7 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -357,6 +370,7 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -409,11 +423,11 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
 
     def aggregated_list(
         self,
-        request: Union[compute.AggregatedListUrlMapsRequest, dict] = None,
+        request: Optional[Union[compute.AggregatedListUrlMapsRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Retrieves the list of all UrlMap resources, regional
@@ -497,12 +511,12 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
 
     def delete_unary(
         self,
-        request: Union[compute.DeleteUrlMapRequest, dict] = None,
+        request: Optional[Union[compute.DeleteUrlMapRequest, dict]] = None,
         *,
-        project: str = None,
-        url_map: str = None,
+        project: Optional[str] = None,
+        url_map: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Deletes the specified UrlMap resource.
@@ -586,12 +600,12 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
 
     def delete(
         self,
-        request: Union[compute.DeleteUrlMapRequest, dict] = None,
+        request: Optional[Union[compute.DeleteUrlMapRequest, dict]] = None,
         *,
-        project: str = None,
-        url_map: str = None,
+        project: Optional[str] = None,
+        url_map: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Deletes the specified UrlMap resource.
@@ -699,12 +713,12 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
 
     def get(
         self,
-        request: Union[compute.GetUrlMapRequest, dict] = None,
+        request: Optional[Union[compute.GetUrlMapRequest, dict]] = None,
         *,
-        project: str = None,
-        url_map: str = None,
+        project: Optional[str] = None,
+        url_map: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.UrlMap:
         r"""Returns the specified UrlMap resource. Gets a list of
@@ -808,12 +822,12 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
 
     def insert_unary(
         self,
-        request: Union[compute.InsertUrlMapRequest, dict] = None,
+        request: Optional[Union[compute.InsertUrlMapRequest, dict]] = None,
         *,
-        project: str = None,
-        url_map_resource: compute.UrlMap = None,
+        project: Optional[str] = None,
+        url_map_resource: Optional[compute.UrlMap] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Creates a UrlMap resource in the specified project
@@ -891,12 +905,12 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
 
     def insert(
         self,
-        request: Union[compute.InsertUrlMapRequest, dict] = None,
+        request: Optional[Union[compute.InsertUrlMapRequest, dict]] = None,
         *,
-        project: str = None,
-        url_map_resource: compute.UrlMap = None,
+        project: Optional[str] = None,
+        url_map_resource: Optional[compute.UrlMap] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Creates a UrlMap resource in the specified project
@@ -998,13 +1012,15 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
 
     def invalidate_cache_unary(
         self,
-        request: Union[compute.InvalidateCacheUrlMapRequest, dict] = None,
+        request: Optional[Union[compute.InvalidateCacheUrlMapRequest, dict]] = None,
         *,
-        project: str = None,
-        url_map: str = None,
-        cache_invalidation_rule_resource: compute.CacheInvalidationRule = None,
+        project: Optional[str] = None,
+        url_map: Optional[str] = None,
+        cache_invalidation_rule_resource: Optional[
+            compute.CacheInvalidationRule
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Initiates a cache invalidation operation, invalidating the
@@ -1101,13 +1117,15 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
 
     def invalidate_cache(
         self,
-        request: Union[compute.InvalidateCacheUrlMapRequest, dict] = None,
+        request: Optional[Union[compute.InvalidateCacheUrlMapRequest, dict]] = None,
         *,
-        project: str = None,
-        url_map: str = None,
-        cache_invalidation_rule_resource: compute.CacheInvalidationRule = None,
+        project: Optional[str] = None,
+        url_map: Optional[str] = None,
+        cache_invalidation_rule_resource: Optional[
+            compute.CacheInvalidationRule
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Initiates a cache invalidation operation, invalidating the
@@ -1228,11 +1246,11 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
 
     def list(
         self,
-        request: Union[compute.ListUrlMapsRequest, dict] = None,
+        request: Optional[Union[compute.ListUrlMapsRequest, dict]] = None,
         *,
-        project: str = None,
+        project: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
         r"""Retrieves the list of UrlMap resources available to
@@ -1314,13 +1332,13 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
 
     def patch_unary(
         self,
-        request: Union[compute.PatchUrlMapRequest, dict] = None,
+        request: Optional[Union[compute.PatchUrlMapRequest, dict]] = None,
         *,
-        project: str = None,
-        url_map: str = None,
-        url_map_resource: compute.UrlMap = None,
+        project: Optional[str] = None,
+        url_map: Optional[str] = None,
+        url_map_resource: Optional[compute.UrlMap] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Patches the specified UrlMap resource with the data
@@ -1412,13 +1430,13 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
 
     def patch(
         self,
-        request: Union[compute.PatchUrlMapRequest, dict] = None,
+        request: Optional[Union[compute.PatchUrlMapRequest, dict]] = None,
         *,
-        project: str = None,
-        url_map: str = None,
-        url_map_resource: compute.UrlMap = None,
+        project: Optional[str] = None,
+        url_map: Optional[str] = None,
+        url_map_resource: Optional[compute.UrlMap] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Patches the specified UrlMap resource with the data
@@ -1534,13 +1552,13 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
 
     def update_unary(
         self,
-        request: Union[compute.UpdateUrlMapRequest, dict] = None,
+        request: Optional[Union[compute.UpdateUrlMapRequest, dict]] = None,
         *,
-        project: str = None,
-        url_map: str = None,
-        url_map_resource: compute.UrlMap = None,
+        project: Optional[str] = None,
+        url_map: Optional[str] = None,
+        url_map_resource: Optional[compute.UrlMap] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.Operation:
         r"""Updates the specified UrlMap resource with the data
@@ -1632,13 +1650,13 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
 
     def update(
         self,
-        request: Union[compute.UpdateUrlMapRequest, dict] = None,
+        request: Optional[Union[compute.UpdateUrlMapRequest, dict]] = None,
         *,
-        project: str = None,
-        url_map: str = None,
-        url_map_resource: compute.UrlMap = None,
+        project: Optional[str] = None,
+        url_map: Optional[str] = None,
+        url_map_resource: Optional[compute.UrlMap] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> extended_operation.ExtendedOperation:
         r"""Updates the specified UrlMap resource with the data
@@ -1754,13 +1772,15 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
 
     def validate(
         self,
-        request: Union[compute.ValidateUrlMapRequest, dict] = None,
+        request: Optional[Union[compute.ValidateUrlMapRequest, dict]] = None,
         *,
-        project: str = None,
-        url_map: str = None,
-        url_maps_validate_request_resource: compute.UrlMapsValidateRequest = None,
+        project: Optional[str] = None,
+        url_map: Optional[str] = None,
+        url_maps_validate_request_resource: Optional[
+            compute.UrlMapsValidateRequest
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.UrlMapsValidateResponse:
         r"""Runs static validation for the UrlMap. In particular,
@@ -1868,14 +1888,9 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-compute",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("UrlMapsClient",)
