@@ -17,9 +17,7 @@ from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import VpnGatewaysTransport
-from .rest import VpnGatewaysRestTransport
-from .rest import VpnGatewaysRestInterceptor
-
+from .rest import VpnGatewaysRestInterceptor, VpnGatewaysRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[VpnGatewaysTransport]]
